@@ -30,13 +30,13 @@
  * Tests of C API for attributes.
  */
 
+#include <test/support/tdb_catch.h>
 #include "tiledb/sm/c_api/tiledb.h"
 
 #include <iostream>
 
-#include <test/support/tdb_catch.h>
-#include "test/src/helpers.h"
-#include "test/src/vfs_helpers.h"
+#include "test/support/src/helpers.h"
+#include "test/support/src/vfs_helpers.h"
 #ifdef _WIN32
 #include <Windows.h>
 #include "tiledb/sm/filesystem/win.h"
@@ -169,11 +169,11 @@ TEST_CASE_METHOD(
   SECTION("no serialization") {
     serialized_writes = false;
   }
-  SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
+  SECTION("serialization enabled global order write") {
     serialized_writes = true;
-#endif
   }
+#endif
 
   for (const auto& attr_name : attr_names) {
     for (const auto& fs : fs_vec_) {
@@ -283,11 +283,11 @@ TEST_CASE_METHOD(
   SECTION("no serialization") {
     serialized_writes = false;
   }
-  SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
+  SECTION("serialization enabled global order write") {
     serialized_writes = true;
-#endif
   }
+#endif
   for (const auto& fs : fs_vec_) {
     std::string temp_dir = fs->temp_dir();
     std::string array_name = temp_dir;
@@ -399,11 +399,11 @@ TEST_CASE_METHOD(
   SECTION("no serialization") {
     serialized_writes = false;
   }
-  SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
+  SECTION("serialization enabled global order write") {
     serialized_writes = true;
-#endif
   }
+#endif
   for (const auto& fs : fs_vec_) {
     std::string temp_dir = fs->temp_dir();
     std::string array_name = temp_dir;
