@@ -50,41 +50,6 @@ TEST_CASE("C API: Test enum values", "[capi][enums]") {
    * don't modify the checks below), otherwise backwards compatibility breaks.
    */
 
-  /** Query type */
-  REQUIRE(TILEDB_READ == 0);
-  REQUIRE(TILEDB_WRITE == 1);
-
-  /** Object type */
-  REQUIRE(TILEDB_INVALID == 0);
-  REQUIRE(TILEDB_GROUP == 1);
-  REQUIRE(TILEDB_ARRAY == 2);
-
-  /** Filesystem type */
-  REQUIRE(TILEDB_HDFS == 0);
-  REQUIRE(TILEDB_S3 == 1);
-
-  /** Datatype */
-  REQUIRE(TILEDB_INT32 == 0);
-  REQUIRE(TILEDB_INT64 == 1);
-  REQUIRE(TILEDB_FLOAT32 == 2);
-  REQUIRE(TILEDB_FLOAT64 == 3);
-  REQUIRE(TILEDB_CHAR == 4);
-  REQUIRE(TILEDB_INT8 == 5);
-  REQUIRE(TILEDB_UINT8 == 6);
-  REQUIRE(TILEDB_INT16 == 7);
-  REQUIRE(TILEDB_UINT16 == 8);
-  REQUIRE(TILEDB_UINT32 == 9);
-  REQUIRE(TILEDB_UINT64 == 10);
-  REQUIRE(TILEDB_STRING_ASCII == 11);
-  REQUIRE(TILEDB_STRING_UTF8 == 12);
-  REQUIRE(TILEDB_STRING_UTF16 == 13);
-  REQUIRE(TILEDB_STRING_UTF32 == 14);
-  REQUIRE(TILEDB_STRING_UCS2 == 15);
-  REQUIRE(TILEDB_STRING_UCS4 == 16);
-  REQUIRE(TILEDB_ANY == 17);
-  REQUIRE(TILEDB_BLOB == 40);
-  REQUIRE(TILEDB_BOOL == 41);
-
   /** Array type */
   REQUIRE(TILEDB_DENSE == 0);
   REQUIRE(TILEDB_SPARSE == 1);
@@ -144,176 +109,6 @@ TEST_CASE("C API: Test enum values", "[capi][enums]") {
 
 TEST_CASE("C API: Test enum string conversion", "[capi][enums]") {
   const char* c_str = nullptr;
-  tiledb_query_type_t query_type;
-  REQUIRE(
-      (tiledb_query_type_to_str(TILEDB_READ, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "READ"));
-  REQUIRE(
-      (tiledb_query_type_from_str("READ", &query_type) == TILEDB_OK &&
-       query_type == TILEDB_READ));
-  REQUIRE(
-      (tiledb_query_type_to_str(TILEDB_WRITE, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "WRITE"));
-  REQUIRE(
-      (tiledb_query_type_from_str("WRITE", &query_type) == TILEDB_OK &&
-       query_type == TILEDB_WRITE));
-
-  tiledb_object_t object_type;
-  REQUIRE(
-      (tiledb_object_type_to_str(TILEDB_INVALID, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "INVALID"));
-  REQUIRE(
-      (tiledb_object_type_from_str("INVALID", &object_type) == TILEDB_OK &&
-       object_type == TILEDB_INVALID));
-  REQUIRE(
-      (tiledb_object_type_to_str(TILEDB_GROUP, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "GROUP"));
-  REQUIRE(
-      (tiledb_object_type_from_str("GROUP", &object_type) == TILEDB_OK &&
-       object_type == TILEDB_GROUP));
-  REQUIRE(
-      (tiledb_object_type_to_str(TILEDB_ARRAY, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "ARRAY"));
-  REQUIRE(
-      (tiledb_object_type_from_str("ARRAY", &object_type) == TILEDB_OK &&
-       object_type == TILEDB_ARRAY));
-
-  tiledb_filesystem_t filesystem;
-  REQUIRE(
-      (tiledb_filesystem_to_str(TILEDB_HDFS, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "HDFS"));
-  REQUIRE(
-      (tiledb_filesystem_from_str("HDFS", &filesystem) == TILEDB_OK &&
-       filesystem == TILEDB_HDFS));
-  REQUIRE(
-      (tiledb_filesystem_to_str(TILEDB_S3, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "S3"));
-  REQUIRE(
-      (tiledb_filesystem_from_str("S3", &filesystem) == TILEDB_OK &&
-       filesystem == TILEDB_S3));
-
-  tiledb_datatype_t datatype;
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_INT32, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "INT32"));
-  REQUIRE(
-      (tiledb_datatype_from_str("INT32", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_INT32));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_INT64, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "INT64"));
-  REQUIRE(
-      (tiledb_datatype_from_str("INT64", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_INT64));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_FLOAT32, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "FLOAT32"));
-  REQUIRE(
-      (tiledb_datatype_from_str("FLOAT32", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_FLOAT32));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_FLOAT64, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "FLOAT64"));
-  REQUIRE(
-      (tiledb_datatype_from_str("FLOAT64", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_FLOAT64));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_CHAR, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "CHAR"));
-  REQUIRE(
-      (tiledb_datatype_from_str("CHAR", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_CHAR));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_BLOB, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "BLOB"));
-  REQUIRE(
-      (tiledb_datatype_from_str("BLOB", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_BLOB));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_BOOL, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "BOOL"));
-  REQUIRE(
-      (tiledb_datatype_from_str("BOOL", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_BOOL));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_INT8, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "INT8"));
-  REQUIRE(
-      (tiledb_datatype_from_str("INT8", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_INT8));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_UINT8, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "UINT8"));
-  REQUIRE(
-      (tiledb_datatype_from_str("UINT8", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_UINT8));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_INT16, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "INT16"));
-  REQUIRE(
-      (tiledb_datatype_from_str("INT16", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_INT16));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_UINT16, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "UINT16"));
-  REQUIRE(
-      (tiledb_datatype_from_str("UINT16", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_UINT16));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_UINT32, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "UINT32"));
-  REQUIRE(
-      (tiledb_datatype_from_str("UINT32", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_UINT32));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_UINT64, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "UINT64"));
-  REQUIRE(
-      (tiledb_datatype_from_str("UINT64", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_UINT64));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_STRING_ASCII, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "STRING_ASCII"));
-  REQUIRE(
-      (tiledb_datatype_from_str("STRING_ASCII", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_STRING_ASCII));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_STRING_UTF8, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "STRING_UTF8"));
-  REQUIRE(
-      (tiledb_datatype_from_str("STRING_UTF8", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_STRING_UTF8));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_STRING_UTF16, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "STRING_UTF16"));
-  REQUIRE(
-      (tiledb_datatype_from_str("STRING_UTF16", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_STRING_UTF16));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_STRING_UTF32, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "STRING_UTF32"));
-  REQUIRE(
-      (tiledb_datatype_from_str("STRING_UTF32", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_STRING_UTF32));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_STRING_UCS2, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "STRING_UCS2"));
-  REQUIRE(
-      (tiledb_datatype_from_str("STRING_UCS2", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_STRING_UCS2));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_STRING_UCS4, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "STRING_UCS4"));
-  REQUIRE(
-      (tiledb_datatype_from_str("STRING_UCS4", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_STRING_UCS4));
-  REQUIRE(
-      (tiledb_datatype_to_str(TILEDB_ANY, &c_str) == TILEDB_OK &&
-       std::string(c_str) == "ANY"));
-  REQUIRE(
-      (tiledb_datatype_from_str("ANY", &datatype) == TILEDB_OK &&
-       datatype == TILEDB_ANY));
-
   tiledb_array_type_t array_type;
   REQUIRE(
       (tiledb_array_type_to_str(TILEDB_DENSE, &c_str) == TILEDB_OK &&
