@@ -32,7 +32,7 @@
  */
 
 #include <test/support/tdb_catch.h>
-#include "helpers.h"
+#include "test/support/src/helpers.h"
 #include "tiledb/sm/buffer/buffer.h"
 #include "tiledb/sm/compressors/rle_compressor.h"
 
@@ -741,4 +741,4 @@ TEST_CASE("Compression-RLE: Test empty input", "[compression][rle][rle-num]") {
   std::vector<uint64_t> decompressed(uncompressed.size());
   tiledb::sm::RLE::decompress<uint64_t>(compressed, decompressed);
   CHECK(decompressed == uncompressed);
-}
\ No newline at end of file
+}
