@@ -31,7 +31,7 @@
  */
 
 #include <test/support/tdb_catch.h>
-#include "helpers.h"
+#include "test/support/src/helpers.h"
 #include "tiledb/sm/cpp_api/tiledb"
 
 using namespace tiledb;
@@ -277,4 +277,4 @@ TEST_CASE(
   REQUIRE(a1_r[1] == 1);
   if (vfs.is_dir(array_name))
     vfs.remove_dir(array_name);
-}
\ No newline at end of file
+}
