@@ -31,7 +31,7 @@
  * Tests the attribute fill values with the C++ API.
  */
 
-#include "catch.hpp"
+#include <test/support/tdb_catch.h>
 #include "tiledb/sm/cpp_api/tiledb"
 #include "tiledb/sm/misc/constants.h"
 
