@@ -32,13 +32,11 @@
  */
 
 #include <test/support/tdb_catch.h>
-#include "test/src/helpers.h"
+#include "test/support/src/helpers.h"
 #include "tiledb/sm/cpp_api/tiledb"
 
 using namespace tiledb;
 
-static bool serialized_writes = false;
-
 void create_sparse_array(const std::string& array_name) {
   Context ctx;
   VFS vfs(ctx);
@@ -66,6 +64,7 @@ void create_sparse_array(const std::string& array_name) {
 void write_sparse_array(
     Context ctx,
     const std::string& array_name,
+    const bool serialized_writes,
     std::vector<int32_t>& data,
     std::vector<uint64_t>& data_offsets,
     tiledb_layout_t layout) {
@@ -80,7 +79,7 @@ void write_sparse_array(
   query.set_data_buffer("attr", data);
   query.set_offsets_buffer("attr", data_offsets);
 
-  if (!serialized_writes || layout != TILEDB_GLOBAL_ORDER) {
+  if (!serialized_writes) {
     CHECK_NOTHROW(query.submit());
     query.finalize();
   } else {
@@ -93,6 +92,7 @@ void write_sparse_array(
 void write_sparse_array(
     Context ctx,
     const std::string& array_name,
+    const bool,  // serialized_writes,
     std::vector<int32_t>& data,
     std::vector<uint32_t>& data_offsets,
     tiledb_layout_t layout) {
@@ -110,7 +110,7 @@ void write_sparse_array(
       reinterpret_cast<uint64_t*>(data_offsets.data()),
       data_offsets.size());
   /* TODO: enable this when sc21681 is fixed
-  if (!serialized_writes || layout != TILEDB_GLOBAL_ORDER) {
+  if (!serialized_writes) {
     CHECK_NOTHROW(query.submit());
     query.finalize();
   } else {
@@ -273,6 +273,7 @@ void create_dense_array(const std::string& array_name) {
 void write_dense_array(
     Context ctx,
     const std::string& array_name,
+    const bool serialized_writes,
     std::vector<int32_t>& data,
     std::vector<uint64_t>& data_offsets,
     tiledb_layout_t layout,
@@ -303,15 +304,7 @@ void write_dense_array(
     query.set_subarray<int64_t>({1, 2, 1, 2});
   }
 
-  SECTION("no serialization") {
-    serialized_writes = false;
-  }
-  SECTION("serialization enabled global order write") {
-#ifdef TILEDB_SERIALIZATION
-    serialized_writes = true;
-#endif
-  }
-  if (!serialized_writes || layout != TILEDB_GLOBAL_ORDER) {
+  if (!serialized_writes) {
     CHECK_NOTHROW(query.submit());
     query.finalize();
   } else {
@@ -324,6 +317,7 @@ void write_dense_array(
 void write_dense_array(
     Context ctx,
     const std::string& array_name,
+    bool serialized_writes,
     std::vector<int32_t>& data,
     std::vector<uint32_t>& data_offsets,
     tiledb_layout_t layout,
@@ -359,17 +353,9 @@ void write_dense_array(
     query.set_subarray<int64_t>({1, 2, 1, 2});
   }
 
-  SECTION("no serialization") {
-    serialized_writes = false;
-  }
-  /* TODO: enable this when sc21681 is fixed
-  SECTION("serialization enabled global order write") {
-#ifdef TILEDB_SERIALIZATION
-    serialized_writes = true;
-#endif
-  }
-  */
-  if (!serialized_writes || layout != TILEDB_GLOBAL_ORDER) {
+  // TODO: remove this when sc21681 is fixed
+  serialized_writes = false;
+  if (!serialized_writes) {
     CHECK_NOTHROW(query.submit());
     query.finalize();
   } else {
@@ -493,7 +479,8 @@ TEST_CASE(
     std::vector<uint64_t> byte_offsets = {0, 4, 12, 20};
 
     SECTION("Unordered write") {
-      write_sparse_array(ctx, array_name, data, byte_offsets, TILEDB_UNORDERED);
+      write_sparse_array(
+          ctx, array_name, false, data, byte_offsets, TILEDB_UNORDERED);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, byte_offsets, TILEDB_ROW_MAJOR);
@@ -508,16 +495,18 @@ TEST_CASE(
       }
     }
     SECTION("Global order write") {
-      SECTION("no serialization") {
-        serialized_writes = false;
-      }
-      SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-        serialized_writes = true;
+      bool serialized_writes = GENERATE(true, false);
+#else
+      bool serialized_writes = false;
 #endif
-      }
       write_sparse_array(
-          ctx, array_name, data, byte_offsets, TILEDB_GLOBAL_ORDER);
+          ctx,
+          array_name,
+          serialized_writes,
+          data,
+          byte_offsets,
+          TILEDB_GLOBAL_ORDER);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, byte_offsets, TILEDB_ROW_MAJOR);
@@ -543,7 +532,7 @@ TEST_CASE(
 
     SECTION("Unordered write") {
       write_sparse_array(
-          ctx, array_name, data, element_offsets, TILEDB_UNORDERED);
+          ctx, array_name, false, data, element_offsets, TILEDB_UNORDERED);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, element_offsets, TILEDB_ROW_MAJOR);
@@ -558,16 +547,18 @@ TEST_CASE(
       }
     }
     SECTION("Global order write") {
-      SECTION("no serialization") {
-        serialized_writes = false;
-      }
-      SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-        serialized_writes = true;
+      bool serialized_writes = GENERATE(true, false);
+#else
+      bool serialized_writes = false;
 #endif
-      }
       write_sparse_array(
-          ctx, array_name, data, element_offsets, TILEDB_GLOBAL_ORDER);
+          ctx,
+          array_name,
+          serialized_writes,
+          data,
+          element_offsets,
+          TILEDB_GLOBAL_ORDER);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, element_offsets, TILEDB_ROW_MAJOR);
@@ -605,12 +596,13 @@ TEST_CASE(
     std::vector<uint64_t> byte_offsets = {0, 4, 12, 20};
 
     SECTION("Ordered write") {
-      write_dense_array(ctx, array_name, data, byte_offsets, TILEDB_ROW_MAJOR);
+      write_dense_array(
+          ctx, array_name, false, data, byte_offsets, TILEDB_ROW_MAJOR);
       read_and_check_dense_array(ctx, array_name, data, byte_offsets);
     }
     SECTION("Global order write") {
       write_dense_array(
-          ctx, array_name, data, byte_offsets, TILEDB_GLOBAL_ORDER);
+          ctx, array_name, false, data, byte_offsets, TILEDB_GLOBAL_ORDER);
       read_and_check_dense_array(ctx, array_name, data, byte_offsets);
     }
   }
@@ -625,12 +617,12 @@ TEST_CASE(
 
     SECTION("Ordered write") {
       write_dense_array(
-          ctx, array_name, data, element_offsets, TILEDB_ROW_MAJOR);
+          ctx, array_name, false, data, element_offsets, TILEDB_ROW_MAJOR);
       read_and_check_dense_array(ctx, array_name, data, element_offsets);
     }
     SECTION("Global order write") {
       write_dense_array(
-          ctx, array_name, data, element_offsets, TILEDB_GLOBAL_ORDER);
+          ctx, array_name, false, data, element_offsets, TILEDB_GLOBAL_ORDER);
       read_and_check_dense_array(ctx, array_name, data, element_offsets);
     }
   }
@@ -659,7 +651,8 @@ TEST_CASE(
       config = ctx.config();
       CHECK((std::string)config["sm.var_offsets.extra_element"] == "false");
 
-      write_sparse_array(ctx, array_name, data, data_offsets, TILEDB_UNORDERED);
+      write_sparse_array(
+          ctx, array_name, false, data, data_offsets, TILEDB_UNORDERED);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, data_offsets, TILEDB_ROW_MAJOR);
@@ -686,7 +679,7 @@ TEST_CASE(
 
         SECTION("Unordered write") {
           write_sparse_array(
-              ctx, array_name, data, data_offsets, TILEDB_UNORDERED);
+              ctx, array_name, false, data, data_offsets, TILEDB_UNORDERED);
           SECTION("Row major read") {
             read_and_check_sparse_array(
                 ctx, array_name, data, data_offsets, TILEDB_ROW_MAJOR);
@@ -701,16 +694,18 @@ TEST_CASE(
           }
         }
         SECTION("Global order write") {
-          SECTION("no serialization") {
-            serialized_writes = false;
-          }
-          SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-            serialized_writes = true;
+          bool serialized_writes = GENERATE(true, false);
+#else
+          bool serialized_writes = false;
 #endif
-          }
           write_sparse_array(
-              ctx, array_name, data, data_offsets, TILEDB_GLOBAL_ORDER);
+              ctx,
+              array_name,
+              serialized_writes,
+              data,
+              data_offsets,
+              TILEDB_GLOBAL_ORDER);
           SECTION("Row major read") {
             read_and_check_sparse_array(
                 ctx, array_name, data, data_offsets, TILEDB_ROW_MAJOR);
@@ -735,7 +730,7 @@ TEST_CASE(
 
         SECTION("Unordered write") {
           write_sparse_array(
-              ctx, array_name, data, element_offsets, TILEDB_UNORDERED);
+              ctx, array_name, false, data, element_offsets, TILEDB_UNORDERED);
           SECTION("Row major read") {
             read_and_check_sparse_array(
                 ctx, array_name, data, element_offsets, TILEDB_ROW_MAJOR);
@@ -750,16 +745,18 @@ TEST_CASE(
           }
         }
         SECTION("Global order write") {
-          SECTION("no serialization") {
-            serialized_writes = false;
-          }
-          SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-            serialized_writes = true;
+          bool serialized_writes = GENERATE(true, false);
+#else
+          bool serialized_writes = false;
 #endif
-          }
           write_sparse_array(
-              ctx, array_name, data, element_offsets, TILEDB_GLOBAL_ORDER);
+              ctx,
+              array_name,
+              serialized_writes,
+              data,
+              element_offsets,
+              TILEDB_GLOBAL_ORDER);
           SECTION("Row major read") {
             read_and_check_sparse_array(
                 ctx, array_name, data, element_offsets, TILEDB_ROW_MAJOR);
@@ -784,7 +781,7 @@ TEST_CASE(
 
         SECTION("Unordered write") {
           write_sparse_array(
-              ctx, array_name, data, data_offsets, TILEDB_UNORDERED);
+              ctx, array_name, false, data, data_offsets, TILEDB_UNORDERED);
           SECTION("Row major read") {
             read_and_check_empty_coords_array(
                 ctx, array_name, TILEDB_ROW_MAJOR);
@@ -799,16 +796,18 @@ TEST_CASE(
           }
         }
         SECTION("Global order write") {
-          SECTION("no serialization") {
-            serialized_writes = false;
-          }
-          SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-            serialized_writes = true;
+          bool serialized_writes = GENERATE(true, false);
+#else
+          bool serialized_writes = false;
 #endif
-          }
           write_sparse_array(
-              ctx, array_name, data, data_offsets, TILEDB_GLOBAL_ORDER);
+              ctx,
+              array_name,
+              serialized_writes,
+              data,
+              data_offsets,
+              TILEDB_GLOBAL_ORDER);
           SECTION("Row major read") {
             read_and_check_empty_coords_array(
                 ctx, array_name, TILEDB_ROW_MAJOR);
@@ -913,7 +912,8 @@ TEST_CASE(
       config = ctx.config();
       CHECK((std::string)config["sm.var_offsets.extra_element"] == "false");
 
-      write_sparse_array(ctx, array_name, data, data_offsets, TILEDB_UNORDERED);
+      write_sparse_array(
+          ctx, array_name, false, data, data_offsets, TILEDB_UNORDERED);
       SECTION("Row major read") {
         partial_read_and_check_sparse_array(
             ctx,
@@ -962,7 +962,7 @@ TEST_CASE(
 
         SECTION("Unordered write") {
           write_sparse_array(
-              ctx, array_name, data, data_offsets, TILEDB_UNORDERED);
+              ctx, array_name, false, data, data_offsets, TILEDB_UNORDERED);
           SECTION("Row major read") {
             partial_read_and_check_sparse_array(
                 ctx,
@@ -995,16 +995,18 @@ TEST_CASE(
           }
         }
         SECTION("Global order write") {
-          SECTION("no serialization") {
-            serialized_writes = false;
-          }
-          SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-            serialized_writes = true;
+          bool serialized_writes = GENERATE(true, false);
+#else
+          bool serialized_writes = false;
 #endif
-          }
           write_sparse_array(
-              ctx, array_name, data, data_offsets, TILEDB_GLOBAL_ORDER);
+              ctx,
+              array_name,
+              serialized_writes,
+              data,
+              data_offsets,
+              TILEDB_GLOBAL_ORDER);
           SECTION("Row major read") {
             partial_read_and_check_sparse_array(
                 ctx,
@@ -1051,7 +1053,7 @@ TEST_CASE(
 
         SECTION("Unordered write") {
           write_sparse_array(
-              ctx, array_name, data, element_offsets, TILEDB_UNORDERED);
+              ctx, array_name, false, data, element_offsets, TILEDB_UNORDERED);
           SECTION("Row major read") {
             partial_read_and_check_sparse_array(
                 ctx,
@@ -1084,16 +1086,18 @@ TEST_CASE(
           }
         }
         SECTION("Global order write") {
-          SECTION("no serialization") {
-            serialized_writes = false;
-          }
-          SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-            serialized_writes = true;
+          bool serialized_writes = GENERATE(true, false);
+#else
+          bool serialized_writes = false;
 #endif
-          }
           write_sparse_array(
-              ctx, array_name, data, element_offsets, TILEDB_GLOBAL_ORDER);
+              ctx,
+              array_name,
+              serialized_writes,
+              data,
+              element_offsets,
+              TILEDB_GLOBAL_ORDER);
           SECTION("Row major read") {
             partial_read_and_check_sparse_array(
                 ctx,
@@ -1131,7 +1135,7 @@ TEST_CASE(
         // Write data with extra element
         data_offsets.push_back(sizeof(data[0]) * data.size());
         write_sparse_array(
-            ctx, array_name, data, data_offsets, TILEDB_UNORDERED);
+            ctx, array_name, false, data, data_offsets, TILEDB_UNORDERED);
 
         // Submit read query
         Context ctx(config);
@@ -1232,7 +1236,8 @@ TEST_CASE(
       config = ctx.config();
       CHECK((std::string)config["sm.var_offsets.extra_element"] == "false");
 
-      write_dense_array(ctx, array_name, data, data_offsets, TILEDB_ROW_MAJOR);
+      write_dense_array(
+          ctx, array_name, false, data, data_offsets, TILEDB_ROW_MAJOR);
       read_and_check_dense_array(ctx, array_name, data, data_offsets);
     }
 
@@ -1248,12 +1253,12 @@ TEST_CASE(
 
         SECTION("Ordered write") {
           write_dense_array(
-              ctx, array_name, data, data_offsets, TILEDB_ROW_MAJOR);
+              ctx, array_name, false, data, data_offsets, TILEDB_ROW_MAJOR);
           read_and_check_dense_array(ctx, array_name, data, data_offsets);
         }
         SECTION("Global order write") {
           write_dense_array(
-              ctx, array_name, data, data_offsets, TILEDB_GLOBAL_ORDER);
+              ctx, array_name, false, data, data_offsets, TILEDB_GLOBAL_ORDER);
           read_and_check_dense_array(ctx, array_name, data, data_offsets);
         }
       }
@@ -1268,12 +1273,17 @@ TEST_CASE(
 
         SECTION("Ordered write") {
           write_dense_array(
-              ctx, array_name, data, element_offsets, TILEDB_ROW_MAJOR);
+              ctx, array_name, false, data, element_offsets, TILEDB_ROW_MAJOR);
           read_and_check_dense_array(ctx, array_name, data, element_offsets);
         }
         SECTION("Global order write") {
           write_dense_array(
-              ctx, array_name, data, element_offsets, TILEDB_GLOBAL_ORDER);
+              ctx,
+              array_name,
+              false,
+              data,
+              element_offsets,
+              TILEDB_GLOBAL_ORDER);
           read_and_check_dense_array(ctx, array_name, data, element_offsets);
         }
       }
@@ -1361,7 +1371,8 @@ TEST_CASE(
       config = ctx.config();
       CHECK((std::string)config["sm.var_offsets.extra_element"] == "false");
 
-      write_dense_array(ctx, array_name, data, data_offsets, TILEDB_ROW_MAJOR);
+      write_dense_array(
+          ctx, array_name, false, data, data_offsets, TILEDB_ROW_MAJOR);
       partial_read_and_check_dense_array(
           ctx,
           array_name,
@@ -1387,7 +1398,7 @@ TEST_CASE(
 
         SECTION("Ordered write") {
           write_dense_array(
-              ctx, array_name, data, data_offsets, TILEDB_ROW_MAJOR);
+              ctx, array_name, false, data, data_offsets, TILEDB_ROW_MAJOR);
           partial_read_and_check_dense_array(
               ctx,
               array_name,
@@ -1398,7 +1409,7 @@ TEST_CASE(
         }
         SECTION("Global order write") {
           write_dense_array(
-              ctx, array_name, data, data_offsets, TILEDB_GLOBAL_ORDER);
+              ctx, array_name, false, data, data_offsets, TILEDB_GLOBAL_ORDER);
           partial_read_and_check_dense_array(
               ctx,
               array_name,
@@ -1422,7 +1433,7 @@ TEST_CASE(
 
         SECTION("Ordered write") {
           write_dense_array(
-              ctx, array_name, data, element_offsets, TILEDB_ROW_MAJOR);
+              ctx, array_name, false, data, element_offsets, TILEDB_ROW_MAJOR);
           partial_read_and_check_dense_array(
               ctx,
               array_name,
@@ -1433,7 +1444,12 @@ TEST_CASE(
         }
         SECTION("Global order write") {
           write_dense_array(
-              ctx, array_name, data, element_offsets, TILEDB_GLOBAL_ORDER);
+              ctx,
+              array_name,
+              false,
+              data,
+              element_offsets,
+              TILEDB_GLOBAL_ORDER);
           partial_read_and_check_dense_array(
               ctx,
               array_name,
@@ -1449,7 +1465,7 @@ TEST_CASE(
         // Write data with extra element
         data_offsets.push_back(sizeof(data[0]) * data.size());
         write_dense_array(
-            ctx, array_name, data, data_offsets, TILEDB_ROW_MAJOR);
+            ctx, array_name, false, data, data_offsets, TILEDB_ROW_MAJOR);
 
         // Submit read query
         Array array(ctx, array_name, TILEDB_READ);
@@ -1552,7 +1568,7 @@ TEST_CASE(
 
     SECTION("Unordered write") {
       write_sparse_array(
-          ctx, array_name, data, data_byte_offsets, TILEDB_UNORDERED);
+          ctx, array_name, false, data, data_byte_offsets, TILEDB_UNORDERED);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, data_byte_offsets, TILEDB_ROW_MAJOR);
@@ -1567,16 +1583,18 @@ TEST_CASE(
       }
     }
     SECTION("Global order write") {
-      SECTION("no serialization") {
-        serialized_writes = false;
-      }
-      SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-        serialized_writes = true;
+      bool serialized_writes = GENERATE(true, false);
+#else
+      bool serialized_writes = false;
 #endif
-      }
       write_sparse_array(
-          ctx, array_name, data, data_byte_offsets, TILEDB_GLOBAL_ORDER);
+          ctx,
+          array_name,
+          serialized_writes,
+          data,
+          data_byte_offsets,
+          TILEDB_GLOBAL_ORDER);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, data_byte_offsets, TILEDB_ROW_MAJOR);
@@ -1602,7 +1620,7 @@ TEST_CASE(
 
     SECTION("Unordered write") {
       write_sparse_array(
-          ctx, array_name, data, data_element_offsets, TILEDB_UNORDERED);
+          ctx, array_name, false, data, data_element_offsets, TILEDB_UNORDERED);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, data_element_offsets, TILEDB_ROW_MAJOR);
@@ -1617,16 +1635,18 @@ TEST_CASE(
       }
     }
     SECTION("Global order write") {
-      SECTION("no serialization") {
-        serialized_writes = false;
-      }
-      SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-        serialized_writes = true;
+      bool serialized_writes = GENERATE(true, false);
+#else
+      bool serialized_writes = false;
 #endif
-      }
       write_sparse_array(
-          ctx, array_name, data, data_element_offsets, TILEDB_GLOBAL_ORDER);
+          ctx,
+          array_name,
+          serialized_writes,
+          data,
+          data_element_offsets,
+          TILEDB_GLOBAL_ORDER);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, data_element_offsets, TILEDB_ROW_MAJOR);
@@ -1652,7 +1672,7 @@ TEST_CASE(
 
     SECTION("Unordered write") {
       write_sparse_array(
-          ctx, array_name, data, data_byte_offsets, TILEDB_UNORDERED);
+          ctx, array_name, false, data, data_byte_offsets, TILEDB_UNORDERED);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, data_byte_offsets, TILEDB_ROW_MAJOR);
@@ -1667,16 +1687,18 @@ TEST_CASE(
       }
     }
     SECTION("Global order write") {
-      SECTION("no serialization") {
-        serialized_writes = false;
-      }
-      SECTION("serialization enabled global order write") {
 #ifdef TILEDB_SERIALIZATION
-        serialized_writes = true;
+      bool serialized_writes = GENERATE(true, false);
+#else
+      bool serialized_writes = false;
 #endif
-      }
       write_sparse_array(
-          ctx, array_name, data, data_byte_offsets, TILEDB_GLOBAL_ORDER);
+          ctx,
+          array_name,
+          serialized_writes,
+          data,
+          data_byte_offsets,
+          TILEDB_GLOBAL_ORDER);
       SECTION("Row major read") {
         read_and_check_sparse_array(
             ctx, array_name, data, data_byte_offsets, TILEDB_ROW_MAJOR);
@@ -1722,12 +1744,12 @@ TEST_CASE(
 
     SECTION("Ordered write") {
       write_dense_array(
-          ctx, array_name, data, data_byte_offsets, TILEDB_ROW_MAJOR);
+          ctx, array_name, false, data, data_byte_offsets, TILEDB_ROW_MAJOR);
       read_and_check_dense_array(ctx, array_name, data, data_byte_offsets);
     }
     SECTION("Global order write") {
       write_dense_array(
-          ctx, array_name, data, data_byte_offsets, TILEDB_GLOBAL_ORDER);
+          ctx, array_name, false, data, data_byte_offsets, TILEDB_GLOBAL_ORDER);
       read_and_check_dense_array(ctx, array_name, data, data_byte_offsets);
     }
   }
@@ -1742,12 +1764,17 @@ TEST_CASE(
 
     SECTION("Ordered write") {
       write_dense_array(
-          ctx, array_name, data, data_element_offsets, TILEDB_ROW_MAJOR);
+          ctx, array_name, false, data, data_element_offsets, TILEDB_ROW_MAJOR);
       read_and_check_dense_array(ctx, array_name, data, data_element_offsets);
     }
     SECTION("Global order write") {
       write_dense_array(
-          ctx, array_name, data, data_element_offsets, TILEDB_GLOBAL_ORDER);
+          ctx,
+          array_name,
+          false,
+          data,
+          data_element_offsets,
+          TILEDB_GLOBAL_ORDER);
       read_and_check_dense_array(ctx, array_name, data, data_element_offsets);
     }
   }
@@ -1762,12 +1789,12 @@ TEST_CASE(
 
     SECTION("Ordered write") {
       write_dense_array(
-          ctx, array_name, data, data_byte_offsets, TILEDB_ROW_MAJOR);
+          ctx, array_name, false, data, data_byte_offsets, TILEDB_ROW_MAJOR);
       read_and_check_dense_array(ctx, array_name, data, data_byte_offsets);
     }
     SECTION("Global order write") {
       write_dense_array(
-          ctx, array_name, data, data_byte_offsets, TILEDB_GLOBAL_ORDER);
+          ctx, array_name, false, data, data_byte_offsets, TILEDB_GLOBAL_ORDER);
       read_and_check_dense_array(ctx, array_name, data, data_byte_offsets);
     }
   }
