@@ -32,7 +32,7 @@
 
 #include <test/support/tdb_catch.h>
 #include <atomic>
-#include "test/src/helpers.h"
+#include "test/support/src/helpers.h"
 #include "tiledb/sm/filesystem/vfs.h"
 #ifdef _WIN32
 #include "tiledb/sm/filesystem/path_win.h"
@@ -46,16 +46,14 @@ using namespace tiledb::test;
 TEST_CASE("VFS: Test read batching", "[vfs]") {
   ThreadPool compute_tp(4);
   ThreadPool io_tp(4);
-
   URI testfile("vfs_unit_test_data");
-  std::unique_ptr<VFS> vfs(new VFS);
-  REQUIRE(
-      vfs->init(&g_helper_stats, &compute_tp, &io_tp, nullptr, nullptr).ok());
+  std::unique_ptr<VFS> vfs(
+      new VFS(&g_helper_stats, &compute_tp, &io_tp, Config{}));
 
   bool exists = false;
   REQUIRE(vfs->is_file(testfile, &exists).ok());
   if (exists) {
-    vfs->remove_file(testfile);
+    REQUIRE(vfs->remove_file(testfile).ok());
   }
 
   // Write some data.
@@ -65,11 +63,12 @@ TEST_CASE("VFS: Test read batching", "[vfs]") {
     data_write[i] = i;
   }
   REQUIRE(vfs->write(testfile, data_write, nelts * sizeof(uint32_t)).ok());
-  REQUIRE(vfs->terminate().ok());
 
-  Tile tile[nelts];
+  std::vector<Tile> tile;
+  tile.reserve(nelts);
   for (uint64_t i = 0; i < nelts; i++) {
-    tile[i].filtered_buffer().expand(nelts * sizeof(uint32_t));
+    tile.emplace_back(Tile(
+        0, Datatype::UINT64, sizeof(uint64_t), 0, 1, nelts * sizeof(uint32_t)));
   }
 
   std::vector<tuple<uint64_t, Tile*, uint64_t>> batches;
@@ -79,9 +78,8 @@ TEST_CASE("VFS: Test read batching", "[vfs]") {
     // Check reading in one batch: single read operation.
     std::memset(tile[0].filtered_buffer().data(), 0, nelts * sizeof(uint32_t));
     batches.emplace_back(0, &tile[0], nelts * sizeof(uint32_t));
-    REQUIRE(
-        vfs->init(&g_helper_stats, &compute_tp, &io_tp, nullptr, nullptr).ok());
-    REQUIRE(vfs->read_all(testfile, batches, &io_tp, &tasks).ok());
+    VFS vfs{&g_helper_stats, &compute_tp, &io_tp, Config{}};
+    REQUIRE(vfs.read_all(testfile, batches, &io_tp, &tasks).ok());
     REQUIRE(io_tp.wait_all(tasks).ok());
     tasks.clear();
     for (unsigned i = 0; i < nelts; i++)
@@ -95,7 +93,7 @@ TEST_CASE("VFS: Test read batching", "[vfs]") {
     batches.emplace_back(0, &tile[0], sizeof(uint32_t));
     batches.emplace_back(
         (nelts - 1) * sizeof(uint32_t), &tile[1], sizeof(uint32_t));
-    REQUIRE(vfs->read_all(testfile, batches, &io_tp, &tasks).ok());
+    REQUIRE(vfs.read_all(testfile, batches, &io_tp, &tasks).ok());
     REQUIRE(io_tp.wait_all(tasks).ok());
     tasks.clear();
     REQUIRE(tile[0].filtered_buffer().data_as<uint32_t>()[0] == 0);
@@ -109,32 +107,25 @@ TEST_CASE("VFS: Test read batching", "[vfs]") {
           tile[i].filtered_buffer().data(), 0, nelts * sizeof(uint32_t));
       batches.emplace_back(i * sizeof(uint32_t), &tile[i], sizeof(uint32_t));
     }
-    REQUIRE(vfs->read_all(testfile, batches, &io_tp, &tasks).ok());
+    REQUIRE(vfs.read_all(testfile, batches, &io_tp, &tasks).ok());
     REQUIRE(io_tp.wait_all(tasks).ok());
     tasks.clear();
     for (unsigned i = 0; i < nelts; i++) {
       REQUIRE(tile[i].filtered_buffer().data_as<uint32_t>()[0] == i);
     }
-    REQUIRE(vfs->terminate().ok());
   }
 
   SECTION("- Reduce min batch size and min batch gap") {
     // Set a smaller min batch size and min batch gap
-    Config default_config, vfs_config;
-    vfs_config.set("vfs.min_batch_size", "0");
-    vfs_config.set("vfs.min_batch_gap", "0");
-    REQUIRE(vfs->init(
-                   &g_helper_stats,
-                   &compute_tp,
-                   &io_tp,
-                   &default_config,
-                   &vfs_config)
-                .ok());
+    Config config;
+    CHECK(config.set("vfs.min_batch_size", "0").ok());
+    CHECK(config.set("vfs.min_batch_gap", "0").ok());
+    VFS vfs{&g_helper_stats, &compute_tp, &io_tp, config};
 
     // Check large batches are not split up.
     std::memset(tile[0].filtered_buffer().data(), 0, nelts * sizeof(uint32_t));
     batches.emplace_back(0, &tile[0], nelts * sizeof(uint32_t));
-    REQUIRE(vfs->read_all(testfile, batches, &io_tp, &tasks).ok());
+    REQUIRE(vfs.read_all(testfile, batches, &io_tp, &tasks).ok());
     REQUIRE(io_tp.wait_all(tasks).ok());
     tasks.clear();
     for (unsigned i = 0; i < nelts; i++) {
@@ -150,7 +141,7 @@ TEST_CASE("VFS: Test read batching", "[vfs]") {
       batches.emplace_back(
           2 * i * sizeof(uint32_t), &tile[i], sizeof(uint32_t));
     }
-    REQUIRE(vfs->read_all(testfile, batches, &io_tp, &tasks).ok());
+    REQUIRE(vfs.read_all(testfile, batches, &io_tp, &tasks).ok());
     REQUIRE(io_tp.wait_all(tasks).ok());
     tasks.clear();
     for (unsigned i = 0; i < nelts / 2; i++) {
@@ -165,25 +156,18 @@ TEST_CASE("VFS: Test read batching", "[vfs]") {
     batches.emplace_back(0, &tile[0], sizeof(uint32_t));
     batches.emplace_back(
         (nelts - 1) * sizeof(uint32_t), &tile[1], sizeof(uint32_t));
-    REQUIRE(vfs->read_all(testfile, batches, &io_tp, &tasks).ok());
+    REQUIRE(vfs.read_all(testfile, batches, &io_tp, &tasks).ok());
     REQUIRE(io_tp.wait_all(tasks).ok());
     tasks.clear();
     REQUIRE(tile[0].filtered_buffer().data_as<uint32_t>()[0] == 0);
     REQUIRE(tile[1].filtered_buffer().data_as<uint32_t>()[0] == nelts - 1);
-    REQUIRE(vfs->terminate().ok());
   }
 
   SECTION("- Reduce min batch size but not min batch gap") {
     // Set a smaller min batch size
-    Config default_config, vfs_config;
-    vfs_config.set("vfs.min_batch_size", "0");
-    REQUIRE(vfs->init(
-                   &g_helper_stats,
-                   &compute_tp,
-                   &io_tp,
-                   &default_config,
-                   &vfs_config)
-                .ok());
+    Config config;
+    CHECK(config.set("vfs.min_batch_size", "0").ok());
+    VFS vfs{&g_helper_stats, &compute_tp, &io_tp, config};
 
     // There should be a single read due to the gap
     batches.clear();
@@ -192,26 +176,19 @@ TEST_CASE("VFS: Test read batching", "[vfs]") {
           tile[i].filtered_buffer().data(), 0, nelts * sizeof(uint32_t));
       batches.emplace_back(i * sizeof(uint32_t), &tile[i], sizeof(uint32_t));
     }
-    REQUIRE(vfs->read_all(testfile, batches, &io_tp, &tasks).ok());
+    REQUIRE(vfs.read_all(testfile, batches, &io_tp, &tasks).ok());
     REQUIRE(io_tp.wait_all(tasks).ok());
     tasks.clear();
     for (unsigned i = 0; i < nelts; i++) {
       REQUIRE(tile[i].filtered_buffer().data_as<uint32_t>()[0] == i);
     }
-    REQUIRE(vfs->terminate().ok());
   }
 
   SECTION("- Reduce min batch gap but not min batch size") {
     // Set a smaller min batch size
-    Config default_config, vfs_config;
-    vfs_config.set("vfs.min_batch_gap", "0");
-    REQUIRE(vfs->init(
-                   &g_helper_stats,
-                   &compute_tp,
-                   &io_tp,
-                   &default_config,
-                   &vfs_config)
-                .ok());
+    Config config;
+    CHECK(config.set("vfs.min_batch_gap", "0").ok());
+    VFS vfs{&g_helper_stats, &compute_tp, &io_tp, config};
 
     // There should be a single read due to the batch size
     batches.clear();
@@ -220,25 +197,17 @@ TEST_CASE("VFS: Test read batching", "[vfs]") {
           tile[i].filtered_buffer().data(), 0, nelts * sizeof(uint32_t));
       batches.emplace_back(i * sizeof(uint32_t), &tile[i], sizeof(uint32_t));
     }
-    REQUIRE(vfs->read_all(testfile, batches, &io_tp, &tasks).ok());
+    REQUIRE(vfs.read_all(testfile, batches, &io_tp, &tasks).ok());
     REQUIRE(io_tp.wait_all(tasks).ok());
     tasks.clear();
     for (unsigned i = 0; i < nelts; i++) {
       REQUIRE(tile[i].filtered_buffer().data_as<uint32_t>()[0] == i);
     }
-    REQUIRE(vfs->terminate().ok());
   }
 
-  Config default_config, vfs_config;
-  REQUIRE(
-      vfs->init(
-             &g_helper_stats, &compute_tp, &io_tp, &default_config, &vfs_config)
-          .ok());
   REQUIRE(vfs->is_file(testfile, &exists).ok());
   if (exists)
     REQUIRE(vfs->remove_file(testfile).ok());
-
-  REQUIRE(vfs->terminate().ok());
 }
 
 #ifdef _WIN32
@@ -246,11 +215,11 @@ TEST_CASE("VFS: Test read batching", "[vfs]") {
 TEST_CASE("VFS: Test long paths (Win32)", "[vfs][windows]") {
   ThreadPool compute_tp(4);
   ThreadPool io_tp(4);
+  Config config;
 
-  std::unique_ptr<VFS> vfs(new VFS);
+  std::unique_ptr<VFS> vfs(
+      new VFS(&g_helper_stats, &compute_tp, &io_tp, config));
   std::string tmpdir_base = tiledb::sm::Win::current_dir() + "\\tiledb_test\\";
-  REQUIRE(
-      vfs->init(&g_helper_stats, &compute_tp, &io_tp, nullptr, nullptr).ok());
   REQUIRE(vfs->create_dir(URI(tmpdir_base)).ok());
 
   SECTION("- Deep hierarchy") {
@@ -297,10 +266,10 @@ TEST_CASE("VFS: Test long paths (Win32)", "[vfs][windows]") {
 TEST_CASE("VFS: Test long posix paths", "[vfs]") {
   ThreadPool compute_tp(4);
   ThreadPool io_tp(4);
+  Config config;
 
-  std::unique_ptr<VFS> vfs(new VFS);
-  REQUIRE(
-      vfs->init(&g_helper_stats, &compute_tp, &io_tp, nullptr, nullptr).ok());
+  std::unique_ptr<VFS> vfs(
+      new VFS(&g_helper_stats, &compute_tp, &io_tp, config));
 
   std::string tmpdir_base = Posix::current_dir() + "/tiledb_test/";
   REQUIRE(vfs->create_dir(URI(tmpdir_base)).ok());
@@ -341,7 +310,6 @@ TEST_CASE("VFS: Test long posix paths", "[vfs]") {
   }
 
   REQUIRE(vfs->remove_dir(URI(tmpdir_base)).ok());
-  REQUIRE(vfs->terminate().ok());
 }
 
 #endif
@@ -413,9 +381,7 @@ TEST_CASE("VFS: URI semantics", "[vfs][uri]") {
     const URI& root = root_pair.first;
     const Config& config = root_pair.second;
 
-    VFS vfs;
-    REQUIRE(
-        vfs.init(&g_helper_stats, &compute_tp, &io_tp, nullptr, &config).ok());
+    VFS vfs{&g_helper_stats, &compute_tp, &io_tp, config};
 
     bool exists = false;
     if (root.is_s3() || root.is_azure()) {
@@ -491,16 +457,13 @@ TEST_CASE("VFS: URI semantics", "[vfs][uri]") {
     } else {
       REQUIRE(vfs.remove_dir(root).ok());
     }
-    vfs.terminate();
   }
 }
 
 TEST_CASE("VFS: test ls_with_sizes", "[vfs][ls-with-sizes]") {
   ThreadPool compute_tp(4);
   ThreadPool io_tp(4);
-  VFS vfs;
-  REQUIRE(
-      vfs.init(&g_helper_stats, &compute_tp, &io_tp, nullptr, nullptr).ok());
+  VFS vfs{&g_helper_stats, &compute_tp, &io_tp, Config{}};
 
 #ifdef _WIN32
   std::string path = tiledb::sm::Win::current_dir() + "\\vfs_test\\";
@@ -510,10 +473,10 @@ TEST_CASE("VFS: test ls_with_sizes", "[vfs][ls-with-sizes]") {
 #endif
 
   // Clean up
-  bool is_dir;
-  vfs.is_dir(URI(path), &is_dir);
+  bool is_dir = false;
+  REQUIRE(vfs.is_dir(URI(path), &is_dir).ok());
   if (is_dir)
-    vfs.remove_dir(URI(path));
+    REQUIRE(vfs.remove_dir(URI(path)).ok());
 
   std::string dir = path + "ls_dir";
   std::string file = dir + "/file";
@@ -521,11 +484,11 @@ TEST_CASE("VFS: test ls_with_sizes", "[vfs][ls-with-sizes]") {
   std::string subdir_file = subdir + "/file";
 
   // Create directories and files
-  vfs.create_dir(URI(path));
-  vfs.create_dir(URI(dir));
-  vfs.create_dir(URI(subdir));
-  vfs.touch(URI(file));
-  vfs.touch(URI(subdir_file));
+  REQUIRE(vfs.create_dir(URI(path)).ok());
+  REQUIRE(vfs.create_dir(URI(dir)).ok());
+  REQUIRE(vfs.create_dir(URI(subdir)).ok());
+  REQUIRE(vfs.touch(URI(file)).ok());
+  REQUIRE(vfs.touch(URI(subdir_file)).ok());
 
   // Write to file
   std::string s1 = "abcdef";
@@ -559,5 +522,5 @@ TEST_CASE("VFS: test ls_with_sizes", "[vfs][ls-with-sizes]") {
   REQUIRE(children[1].file_size() == 0);
 
   // Clean up
-  vfs.remove_dir(URI(path));
+  REQUIRE(vfs.remove_dir(URI(path)).ok());
 }
