@@ -364,7 +364,7 @@ Catch::Generators::GeneratorWrapper<typename ChooseGenerator<T>::value_type>
 choose(unsigned int k, std::initializer_list<T> list) {
   return Catch::Generators::GeneratorWrapper<
       typename ChooseGenerator<T>::value_type>(
-      std::make_unique<ChooseGenerator<T>>(k, list));
+      Catch::Detail::make_unique<ChooseGenerator<T>>(k, list));
 }
 
 /* ************************************ */
