@@ -32,7 +32,7 @@
 
 #include "tiledb/sm/array/array_directory.h"
 
-#include <catch.hpp>
+#include <test/support/tdb_catch.h>
 #include <iostream>
 
 using namespace tiledb::common;
