@@ -54,13 +54,12 @@ class Buffer;
 class ConstBuffer;
 class Dimension;
 class DimensionLabelReference;
-class DimensionLabelSchema;
 class Domain;
 
 enum class ArrayType : uint8_t;
 enum class Compressor : uint8_t;
 enum class Datatype : uint8_t;
-enum class LabelOrder : uint8_t;
+enum class DataOrder : uint8_t;
 enum class Layout : uint8_t;
 
 /** Specifies the array schema. */
@@ -219,6 +218,16 @@ class ArraySchema {
    */
   Status check_attributes(const std::vector<std::string>& attributes) const;
 
+  /**
+   * Throws an error if the provided schema does not match the definition given
+   * in the dimension label reference.
+   *
+   * @param name The name of the dimension label.
+   * @param schema The dimension label schema to check.
+   */
+  void check_dimension_label_schema(
+      const std::string& name, const ArraySchema& schema) const;
+
   /**
    * Return the filter pipeline for the given attribute/dimension (can be
    * TILEDB_COORDS).
@@ -277,6 +286,8 @@ class ArraySchema {
    */
   Status has_attribute(const std::string& name, bool* has_attr) const;
 
+  bool has_ordered_attributes() const;
+
   /** Returns true if the input name is an attribute. */
   bool is_attr(const std::string& name) const;
 
@@ -334,18 +345,17 @@ class ArraySchema {
    *
    * @param dim_id The index of the dimension the label applied to.
    * @param name The name of the dimension label.
-   * @param dimension_label_schema The schema of the dimension label.
+   * @param label_order The order of the label data.
+   * @param label_type The datda type of the label data.
    * @param check_name If ``true``, check the name does not conflict with other
-   * labels, attributes, or dimensions.
-   * @param check_is_compatible If ``true``, check the schema of the dimension
-   * label is compatible with the defintion of the dimension.
+   *     labels, attributes, or dimensions.
    **/
-  Status add_dimension_label(
+  void add_dimension_label(
       dimension_size_type dim_id,
       const std::string& name,
-      shared_ptr<const DimensionLabelSchema> dimension_label_schema,
-      bool check_name = true,
-      bool check_is_compatible = true);
+      DataOrder label_order,
+      Datatype label_type,
+      bool check_name = true);
 
   /**
    * Drops an attribute.
@@ -401,6 +411,27 @@ class ArraySchema {
   /** Sets the cell order. */
   Status set_cell_order(Layout cell_order);
 
+  /**
+   * Sets a filter on a dimension label filter in an array schema.
+   *
+   * @param label_name The dimension label name.
+   * @param filter_list The filter_list to be set.
+   */
+  void set_dimension_label_filter_pipeline(
+      const std::string& label_name, const FilterPipeline& pipeline);
+
+  /**
+   * Sets the tile extent on a dimension label in an array schema.
+   *
+   * @param label_name The dimension label name.
+   * @param tile_extent The tile extent for the dimension of the dimension
+   * label.
+   */
+  void set_dimension_label_tile_extent(
+      const std::string& label_name,
+      const Datatype type,
+      const void* tile_extent);
+
   /**
    * Sets the domain. The function returns an error if the array has been
    * previously set to be a key-value store.
@@ -522,11 +553,12 @@ class ArraySchema {
   std::vector<shared_ptr<const Attribute>> attributes_;
 
   /** The array dimension labels. */
-  std::vector<shared_ptr<const DimensionLabelReference>> dimension_labels_;
+  std::vector<shared_ptr<const DimensionLabelReference>>
+      dimension_label_references_;
 
   /** A map from the dimension label names to the label schemas. */
   std::unordered_map<std::string, const DimensionLabelReference*>
-      dimension_label_map_;
+      dimension_label_reference_map_;
 
   /** The filter pipeline run on offset tiles for var-length attributes. */
   FilterPipeline cell_var_offsets_filters_;
@@ -559,8 +591,8 @@ class ArraySchema {
   /* ********************************* */
 
   /**
-   * Returns false if the union of attribute and dimension names contain
-   * duplicates.
+   * Throws an error if the union of attribute, dimension, and dimension label
+   * names contain duplicates.
    */
   void check_attribute_dimension_label_names() const;
 
