@@ -28,9 +28,14 @@
 
 #include "tiledb/sm/array_schema/dimension_label_reference.h"
 #include "tiledb/common/common.h"
+#include "tiledb/sm/array_schema/array_schema.h"
+#include "tiledb/sm/array_schema/dimension.h"
+#include "tiledb/sm/array_schema/domain.h"
 #include "tiledb/sm/buffer/buffer.h"
+#include "tiledb/sm/enums/array_type.h"
+#include "tiledb/sm/enums/data_order.h"
 #include "tiledb/sm/enums/datatype.h"
-#include "tiledb/sm/enums/label_order.h"
+#include "tiledb/sm/enums/layout.h"
 #include "tiledb/sm/misc/constants.h"
 #include "tiledb/type/range/range.h"
 
@@ -49,35 +54,40 @@ class DimensionLabelReferenceStatusException : public StatusException {
 
 DimensionLabelReference::DimensionLabelReference(
     dimension_size_type dim_id,
-    const std::string& name,
+    const std::string& dim_label_name,
     const URI& uri,
-    LabelOrder label_order,
+    const std::string& label_attr_name,
+    DataOrder label_order,
     Datatype label_type,
     uint32_t label_cell_val_num,
-    const Range& label_domain,
-    shared_ptr<const DimensionLabelSchema> schema,
+    shared_ptr<ArraySchema> schema,
     bool is_external,
     bool relative_uri)
     : dim_id_(dim_id)
-    , name_(name)
+    , dim_label_name_(dim_label_name)
     , uri_(uri)
+    , label_attr_name_(label_attr_name)
     , label_order_(label_order)
     , label_type_(label_type)
     , label_cell_val_num_(label_cell_val_num)
-    , label_domain_(label_domain)
     , schema_(schema)
     , is_external_(is_external)
     , relative_uri_(relative_uri) {
-  if (name.size() == 0) {
+  if (dim_label_name.size() == 0) {
     throw std::invalid_argument(
-        "Cannot create dimension label reference; Cannot set name to an empty "
-        "string.");
+        "Cannot create dimension label reference; Cannot set the dimension "
+        "label name to an empty string.");
   }
   if (uri.to_string().size() == 0) {
     throw std::invalid_argument(
         "Cannot create dimension label reference; Cannot set the URI to an "
         "emptry string.");
   }
+  if (label_attr_name.size() == 0) {
+    throw std::invalid_argument(
+        "Cannot create dimension label reference; Cannot set the label "
+        "attribute name to an empty string.");
+  }
 
   // Check label type.
   ensure_dimension_datatype_is_valid(label_type);
@@ -88,12 +98,6 @@ DimensionLabelReference::DimensionLabelReference(
           "per coordinate for the string dimension "
           "label.");
     }
-    if (!label_domain.empty() && label_domain.var_size()) {
-      throw std::invalid_argument(
-          "Cannot create dimension label reference; The label domain for a "
-          "dimension label with label type '" +
-          datatype_str(label_type) + "must be variable.");
-    }
   } else {
     if (label_cell_val_num != 1) {
       throw std::invalid_argument(
@@ -101,66 +105,88 @@ DimensionLabelReference::DimensionLabelReference(
           "per coordiante; Currently only one value per coordinate is "
           "supported for non-string dimension labels.");
     }
-    if (!label_domain.empty()) {
-      if (label_domain.var_size()) {
-        throw std::invalid_argument(
-            "Cannot create dimension label reference; The label domain for a "
-            "dimension label with label type '" +
-            datatype_str(label_type) + "cannot be variable.");
-      }
-      if (!label_domain.empty() &&
-          label_domain.size() != 2 * datatype_size(label_type)) {
-        throw std::invalid_argument(
-            "Cannot create dimension label reference; The size of the label "
-            "domain does not match the size of the datatype.");
-      }
-    }
-    if (!is_external_ && !relative_uri_) {
-      throw std::invalid_argument(
-          "Cannot create dimension label reference; Dimension labels stored by "
-          "the array must have a relative URI.");
-    }
+  }
+
+  // Check URI is relative if it is internal to the array.
+  if (!is_external_ && !relative_uri_) {
+    throw std::invalid_argument(
+        "Cannot create dimension label reference; Dimension labels stored by "
+        "the array must have a relative URI.");
   }
 }
 
 DimensionLabelReference::DimensionLabelReference(
     dimension_size_type dim_id,
-    const std::string& name,
+    const std::string& dim_label_name,
     const URI& uri,
-    LabelOrder label_order,
-    Datatype label_type,
-    uint32_t label_cell_val_num,
-    const Range& label_domain,
-    shared_ptr<const DimensionLabelSchema> schema)
-    : DimensionLabelReference(
-          dim_id,
-          name,
-          uri,
-          label_order,
-          label_type,
-          label_cell_val_num,
-          label_domain,
-          schema,
-          false,
-          true) {
+    const Dimension* dim,
+    DataOrder label_order,
+    Datatype label_type)
+    : dim_id_(dim_id)
+    , dim_label_name_(dim_label_name)
+    , uri_(uri)
+    , label_attr_name_("label")
+    , label_order_(label_order)
+    , label_type_(label_type)
+    , label_cell_val_num_(
+          label_type == Datatype::STRING_ASCII ? constants::var_num : 1)
+    , schema_(make_shared<ArraySchema>(
+          HERE(),
+          label_order == DataOrder::UNORDERED_DATA ? ArrayType::SPARSE :
+                                                     ArrayType::DENSE))
+    , is_external_(false)
+    , relative_uri_(true) {
+  auto index_type{dim->type()};
+  if (!(datatype_is_integer(index_type) || datatype_is_datetime(index_type) ||
+        datatype_is_time(index_type))) {
+    throw std::invalid_argument(
+        "Failed to create dimension label schema; Currently labels are not "
+        "support on dimensions with datatype Datatype::" +
+        datatype_str(index_type));
+  }
+
+  // Check the label data type is valid.
+  try {
+    ensure_dimension_datatype_is_valid(label_type);
+  } catch (...) {
+    std::throw_with_nested(std::invalid_argument(
+        "Datatype Datatype::" + datatype_str(label_type) +
+        " is not a valid dimension datatype."));
+  }
+
+  // Create and set dimension label domain.
+  std::vector<shared_ptr<Dimension>> index_dims{
+      make_shared<Dimension>(HERE(), "index", index_type)};
+  throw_if_not_ok(index_dims.back()->set_domain(dim->domain().data()));
+  throw_if_not_ok(
+      index_dims.back()->set_tile_extent(dim->tile_extent().data()));
+  throw_if_not_ok(schema_->set_domain(make_shared<Domain>(
+      HERE(), Layout::ROW_MAJOR, index_dims, Layout::ROW_MAJOR)));
+
+  // Create and set dimension label attribute.
+  auto label_attr = make_shared<Attribute>(
+      HERE(), "label", label_type, label_cell_val_num_, label_order);
+  throw_if_not_ok(schema_->add_attribute(label_attr));
+
+  // Check the array schema is valid.
+  throw_if_not_ok(schema_->check());
 }
 
 // FORMAT:
-//| Field                     | Type       |
-//| ------------------------- | ---------- |
-//| Dimension ID              | `uint32_t` |
-//| Label order               | `uint8_t`  |
-//| Name length               | `uint64_t` |
-//| Name                      | `char []`  |
-//| Relative URI              | `bool`     |
-//| URI length                | `uint64_t` |
-//| URI                       | `char []`  |
-//| Label datatype            | `uint8_t`  |
-//| Label cell_val_num        | `uint32_t` |
-//| Label domain size         | `uint64_t` |
-//| Label domain start size   | `uint64_t` |
-//| Label domain data         | `uint8_t[]`|
-//| Is external               | `bool`     |
+//| Field                      | Type       |
+//| -------------------------- | ---------- |
+//| Dimension ID               | `uint32_t` |
+//| Label order                | `uint8_t`  |
+//| Dimension label name length| `uint64_t` |
+//| Dimension label name       | `char []`  |
+//| Relative URI               | `bool`     |
+//| URI length                 | `uint64_t` |
+//| URI                        | `char []`  |
+//| Label attribute name length| `uint32_t` |
+//| Label attribute name       | `char []`  |
+//| Label datatype             | `uint8_t`  |
+//| Label cell_val_num         | `uint32_t` |
+//| Is external                | `bool`     |
 shared_ptr<DimensionLabelReference> DimensionLabelReference::deserialize(
     Deserializer& deserializer, uint32_t) {
   try {
@@ -168,16 +194,22 @@ shared_ptr<DimensionLabelReference> DimensionLabelReference::deserialize(
     dimension_size_type dim_id = deserializer.read<uint32_t>();
 
     // Read dimension label name
-    uint64_t name_size = deserializer.read<uint64_t>();
-    std::string name(deserializer.get_ptr<char>(name_size), name_size);
+    uint32_t dim_label_name_size = deserializer.read<uint32_t>();
+    std::string dim_label_name(
+        deserializer.get_ptr<char>(dim_label_name_size), dim_label_name_size);
 
     // Read dimension label URI
     auto relative_uri = deserializer.read<bool>();
     auto uri_size = deserializer.read<uint64_t>();
     std::string uri(deserializer.get_ptr<char>(uri_size), uri_size);
 
+    // Read dimension label name
+    uint32_t label_attr_name_size = deserializer.read<uint32_t>();
+    std::string label_attr_name(
+        deserializer.get_ptr<char>(label_attr_name_size), label_attr_name_size);
+
     // Read label order
-    auto label_order = label_order_from_int(deserializer.read<uint8_t>());
+    auto label_order = data_order_from_int(deserializer.read<uint8_t>());
 
     // Read label datatype
     auto label_type = static_cast<Datatype>(deserializer.read<uint8_t>());
@@ -185,29 +217,6 @@ shared_ptr<DimensionLabelReference> DimensionLabelReference::deserialize(
     // Read label cell value number
     auto label_cell_val_num = deserializer.read<uint32_t>();
 
-    // Read label domain
-    Range label_domain;
-    auto label_domain_size = deserializer.read<uint64_t>();
-    auto label_domain_start_size = deserializer.read<uint64_t>();
-    if (label_domain_size != 0) {
-      if (label_domain_start_size == 0) {
-        label_domain = Range(
-            deserializer.get_ptr<uint8_t>(label_domain_size),
-            label_domain_size);
-      } else {
-        auto label_domain_end_size =
-            label_domain_size - label_domain_start_size;
-        auto range_start =
-            deserializer.get_ptr<uint8_t>(label_domain_start_size);
-        auto range_end = deserializer.get_ptr<uint8_t>(label_domain_end_size);
-        label_domain = Range(
-            range_start,
-            label_domain_start_size,
-            range_end,
-            label_domain_end_size);
-      }
-    }
-
     // Read if dimension label is external
     auto is_external = deserializer.read<bool>();
 
@@ -215,12 +224,12 @@ shared_ptr<DimensionLabelReference> DimensionLabelReference::deserialize(
     return make_shared<DimensionLabelReference>(
         HERE(),
         dim_id,
-        name,
+        dim_label_name,
         URI(uri, !relative_uri),
+        label_attr_name,
         label_order,
         label_type,
         label_cell_val_num,
-        label_domain,
         nullptr,
         is_external,
         relative_uri);
@@ -235,44 +244,49 @@ void DimensionLabelReference::dump(FILE* out) const {
     out = stdout;
   fprintf(out, "### Dimension Label ###\n");
   fprintf(out, "- Dimension Index: %i\n", dim_id_);
-  fprintf(out, "- Name: %s\n", name_.c_str());
+  fprintf(out, "- Dimension Label Name: %s\n", dim_label_name_.c_str());
   fprintf(out, "- URI: %s\n", uri_.c_str());
+  fprintf(out, "- Label Attribute Name: %s\n", label_attr_name_.c_str());
   fprintf(out, "- Label Type: %s\n", datatype_str(label_type_).c_str());
   (label_cell_val_num_ == constants::var_num) ?
       fprintf(out, "- Label cell val num: var\n") :
       fprintf(out, "- Label cell val num: %u\n", label_cell_val_num_);
-  fprintf(
-      out,
-      "- Label domain: %s\n",
-      range_str(label_domain_, label_type_).c_str());
   fprintf(out, "\n");
 }
 
+const shared_ptr<ArraySchema> DimensionLabelReference::schema() const {
+  if (!schema_) {
+    throw StatusException(
+        "DimensionLabelReference",
+        "Cannot return dimension label schema; No schema is set.");
+  }
+  return schema_;
+}
+
 // FORMAT:
-//| Field                     | Type       |
-//| ------------------------- | ---------- |
-//| Dimension ID              | `uint32_t` |
-//| Label order               | `uint8_t`  |
-//| Name length               | `uint64_t` |
-//| Name                      | `char []`  |
-//| Relative URI              | `bool`     |
-//| URI length                | `uint64_t` |
-//| URI                       | `char []`  |
-//| Label datatype            | `uint8_t`  |
-//| Label cell_val_num        | `uint32_t` |
-//| Label domain size         | `uint64_t` |
-//| Label domain start size   | `uint64_t` |
-//| Label domain data         | `uint8_t[]`|
-//| Is external               | `bool`     |
+//| Field                      | Type       |
+//| -------------------------- | ---------- |
+//| Dimension ID               | `uint32_t` |
+//| Label order                | `uint8_t`  |
+//| Dimension label name length| `uint32_t` |
+//| Dimension label name       | `char []`  |
+//| Relative URI               | `bool`     |
+//| URI length                 | `uint64_t` |
+//| URI                        | `char []`  |
+//| Label attribute name length| `uint32_t` |
+//| Label attribute name       | `char []`  |
+//| Label datatype             | `uint8_t`  |
+//| Label cell_val_num         | `uint32_t` |
+//| Is external                | `bool`     |
 void DimensionLabelReference::serialize(
     Serializer& serializer, uint32_t) const {
   // Read dimension ID
   serializer.write<uint32_t>(dim_id_);
 
-  // Read dimension label namea
-  uint64_t name_size{name_.size()};
-  serializer.write<uint64_t>(name_size);
-  serializer.write(name_.c_str(), name_size);
+  // Read dimension label name
+  auto dim_label_name_size = static_cast<uint32_t>(dim_label_name_.size());
+  serializer.write<uint32_t>(dim_label_name_size);
+  serializer.write(dim_label_name_.c_str(), dim_label_name_size);
 
   // Read dimension label URI
   serializer.write<bool>(relative_uri_);
@@ -280,6 +294,11 @@ void DimensionLabelReference::serialize(
   serializer.write<uint64_t>(uri_size);
   serializer.write(uri_.c_str(), uri_size);
 
+  // Read dimension label name
+  auto label_attr_name_size = static_cast<uint32_t>(label_attr_name_.size());
+  serializer.write<uint32_t>(label_attr_name_size);
+  serializer.write(label_attr_name_.c_str(), label_attr_name_size);
+
   // Read label order
   serializer.write<uint8_t>(static_cast<uint8_t>(label_order_));
 
@@ -290,12 +309,6 @@ void DimensionLabelReference::serialize(
   // Read label cell value number
   serializer.write<uint32_t>(label_cell_val_num_);
 
-  // Read label domain
-  // Note: start_size is 0 for non-variable length ranges.
-  serializer.write<uint64_t>(label_domain_.size());
-  serializer.write<uint64_t>(label_domain_.start_size());
-  serializer.write(label_domain_.data(), label_domain_.size());
-
   // Write if the dimension label is external
   serializer.write<uint8_t>(static_cast<uint8_t>(is_external_));
 }
