@@ -43,12 +43,19 @@
 #include "tiledb/storage_format/uri/parse_uri.h"
 
 #include <iostream>
+#include <numeric>
 #include <sstream>
 
 using namespace tiledb::common;
 
-namespace tiledb {
-namespace sm {
+namespace tiledb::sm {
+
+class FragmentConsolidatorStatusException : public StatusException {
+ public:
+  explicit FragmentConsolidatorStatusException(const std::string& message)
+      : StatusException("FragmentConsolidator", message) {
+  }
+};
 
 /* ****************************** */
 /*          CONSTRUCTOR           */
@@ -283,10 +290,11 @@ Status FragmentConsolidator::consolidate_fragments(
   return Status::Ok();
 }
 
-Status FragmentConsolidator::vacuum(const char* array_name) {
-  if (array_name == nullptr)
-    return logger_->status(Status_StorageManagerError(
-        "Cannot vacuum fragments; Array name cannot be null"));
+void FragmentConsolidator::vacuum(const char* array_name) {
+  if (array_name == nullptr) {
+    throw Status_StorageManagerError(
+        "Cannot vacuum fragments; Array name cannot be null");
+  }
 
   // Get the fragment URIs and vacuum file URIs to be vacuumed
   auto vfs = storage_manager_->vfs();
@@ -302,45 +310,26 @@ Status FragmentConsolidator::vacuum(const char* array_name) {
   auto filtered_fragment_uris = array_dir.filtered_fragment_uris(true);
   const auto& fragment_uris_to_vacuum =
       filtered_fragment_uris.fragment_uris_to_vacuum();
-  const auto& commit_uris_to_vacuum =
-      filtered_fragment_uris.commit_uris_to_vacuum();
   const auto& commit_uris_to_ignore =
       filtered_fragment_uris.commit_uris_to_ignore();
-  const auto& vac_uris_to_vacuum =
-      filtered_fragment_uris.fragment_vac_uris_to_vacuum();
 
   if (commit_uris_to_ignore.size() > 0) {
-    RETURN_NOT_OK(storage_manager_->write_commit_ignore_file(
+    throw_if_not_ok(storage_manager_->write_commit_ignore_file(
         array_dir, commit_uris_to_ignore));
   }
 
-  // Delete the commit files
-  auto status =
-      parallel_for(compute_tp, 0, commit_uris_to_vacuum.size(), [&](size_t i) {
-        RETURN_NOT_OK(vfs->remove_file(commit_uris_to_vacuum[i]));
-
-        return Status::Ok();
-      });
-  RETURN_NOT_OK(status);
+  // Delete the commit and vacuum files
+  vfs->remove_files(compute_tp, filtered_fragment_uris.commit_uris_to_vacuum());
+  vfs->remove_files(
+      compute_tp, filtered_fragment_uris.fragment_vac_uris_to_vacuum());
 
   // Delete fragment directories
-  status = parallel_for(
+  throw_if_not_ok(parallel_for(
       compute_tp, 0, fragment_uris_to_vacuum.size(), [&](size_t i) {
         RETURN_NOT_OK(vfs->remove_dir(fragment_uris_to_vacuum[i]));
 
         return Status::Ok();
-      });
-  RETURN_NOT_OK(status);
-
-  // Delete vacuum files
-  status =
-      parallel_for(compute_tp, 0, vac_uris_to_vacuum.size(), [&](size_t i) {
-        RETURN_NOT_OK(vfs->remove_file(vac_uris_to_vacuum[i]));
-        return Status::Ok();
-      });
-  RETURN_NOT_OK(status);
-
-  return Status::Ok();
+      }));
 }
 
 /* ****************************** */
@@ -423,9 +412,9 @@ Status FragmentConsolidator::consolidate_internal(
   }
 
   // Prepare buffers
-  std::vector<ByteVec> buffers;
-  std::vector<uint64_t> buffer_sizes;
-  RETURN_NOT_OK(create_buffers(array_schema, &buffers, &buffer_sizes));
+  auto average_var_cell_sizes = array_for_reads->get_average_var_cell_sizes();
+  auto&& [buffers, buffer_sizes] =
+      create_buffers(stats_, config_, array_schema, average_var_cell_sizes);
 
   // Create queries
   auto query_r = (Query*)nullptr;
@@ -513,6 +502,15 @@ Status FragmentConsolidator::copy_array(
     // READ
     RETURN_NOT_OK(query_r->submit());
 
+    // If Consolidation cannot make any progress, throw. The first buffer will
+    // always contain fixed size data, wether it is tile offsets for var size
+    // attribute/dimension or the actual fixed size data so we can use its size
+    // to know if any cells were written or not.
+    if (buffer_sizes->at(0) == 0) {
+      throw FragmentConsolidatorStatusException(
+          "Consolidation read 0 cells, no progress can be made");
+    }
+
     // Set explicitly the write query buffers, as the sizes may have
     // been altered by the read query.
     RETURN_NOT_OK(set_query_buffers(query_w, buffers, buffer_sizes));
@@ -524,11 +522,13 @@ Status FragmentConsolidator::copy_array(
   return Status::Ok();
 }
 
-Status FragmentConsolidator::create_buffers(
+tuple<std::vector<ByteVec>, std::vector<uint64_t>>
+FragmentConsolidator::create_buffers(
+    stats::Stats* stats,
+    const ConsolidationConfig& config,
     const ArraySchema& array_schema,
-    std::vector<ByteVec>* buffers,
-    std::vector<uint64_t>* buffer_sizes) {
-  auto timer_se = stats_->start_timer("consolidate_create_buffers");
+    std::unordered_map<std::string, uint64_t>& avg_cell_sizes) {
+  auto timer_se = stats->start_timer("consolidate_create_buffers");
 
   // For easy reference
   auto attribute_num = array_schema.attribute_num();
@@ -536,38 +536,77 @@ Status FragmentConsolidator::create_buffers(
   auto dim_num = array_schema.dim_num();
   auto sparse = !array_schema.dense();
 
-  // Calculate number of buffers
-  size_t buffer_num = 0;
+  // Calculate buffer weights. We reserve the maximum possible number of buffers
+  // to make only one allocation. If an attribute is var size and nullable, it
+  // has 3 buffers, dimensions only have 2 as they cannot be nullable. Then one
+  // buffer for timestamps, and 2 for delete metadata.
+  std::vector<size_t> buffer_weights;
+  buffer_weights.reserve(attribute_num * 3 + dim_num * 2 + 3);
   for (unsigned i = 0; i < attribute_num; ++i) {
-    buffer_num += (array_schema.attributes()[i]->var_size()) ? 2 : 1;
-    buffer_num += (array_schema.attributes()[i]->nullable()) ? 1 : 0;
+    const auto attr = array_schema.attributes()[i];
+    const auto var_size = attr->var_size();
+
+    // First buffer is either the var size data or the fixed size data.
+    buffer_weights.emplace_back(
+        var_size ? avg_cell_sizes[attr->name()] : attr->cell_size());
+
+    // For var size attributes, add the offsets buffer weight.
+    if (var_size) {
+      buffer_weights.emplace_back(constants::cell_var_offset_size);
+    }
+
+    // For nullable attributes, add the offsets buffer weight.
+    if (attr->nullable()) {
+      buffer_weights.emplace_back(constants::cell_validity_size);
+    }
   }
+
   if (sparse) {
-    for (unsigned i = 0; i < dim_num; ++i)
-      buffer_num += (domain.dimension_ptr(i)->var_size()) ? 2 : 1;
+    for (unsigned i = 0; i < dim_num; ++i) {
+      const auto dim = domain.dimension_ptr(i);
+      const auto var_size = dim->var_size();
+
+      // First buffer is either the var size data or the fixed size data.
+      buffer_weights.emplace_back(
+          var_size ? avg_cell_sizes[dim->name()] : dim->coord_size());
+
+      // For var size attributes, add the offsets buffer weight.
+      if (var_size) {
+        buffer_weights.emplace_back(constants::cell_var_offset_size);
+      }
+    }
   }
-  if (config_.with_timestamps_ && sparse) {
-    buffer_num++;
+
+  if (config.with_timestamps_ && sparse) {
+    buffer_weights.emplace_back(constants::timestamp_size);
   }
 
   // Adding buffers for delete meta, one for timestamp and one for condition
   // index.
-  if (config_.with_delete_meta_) {
-    buffer_num += 2;
+  if (config.with_delete_meta_) {
+    buffer_weights.emplace_back(constants::timestamp_size);
+    buffer_weights.emplace_back(sizeof(uint64_t));
   }
 
-  // Create buffers
-  buffers->resize(buffer_num);
-  buffer_sizes->resize(buffer_num);
+  // Use the old buffer size setting to see how much memory we would use.
+  auto buffer_num = buffer_weights.size();
+  uint64_t total_budget = config.buffer_size_ * buffer_num;
 
-  // Allocate space for each buffer
+  // Create buffers.
+  std::vector<ByteVec> buffers(buffer_num);
+  std::vector<uint64_t> buffer_sizes(buffer_num);
+  auto total_weights =
+      std::accumulate(buffer_weights.begin(), buffer_weights.end(), 0);
+
+  // Allocate space for each buffer.
   for (unsigned i = 0; i < buffer_num; ++i) {
-    (*buffers)[i].resize(config_.buffer_size_);
-    (*buffer_sizes)[i] = config_.buffer_size_;
+    buffer_sizes[i] =
+        std::max<uint64_t>(1, total_budget * buffer_weights[i] / total_weights);
+    buffers[i].resize(buffer_sizes[i]);
   }
 
   // Success
-  return Status::Ok();
+  return {buffers, buffer_sizes};
 }
 
 Status FragmentConsolidator::create_queries(
@@ -764,6 +803,10 @@ Status FragmentConsolidator::set_query_buffers(
   auto dense = array_schema.dense();
   auto attributes = array_schema.attributes();
   unsigned bid = 0;
+
+  // Here the first buffer should always be the fixed buffer (either offsets
+  // or fixed data) as we use the first buffer size to determine if any cells
+  // were written or not.
   for (const auto& attr : attributes) {
     if (!attr->var_size()) {
       if (!attr->nullable()) {
@@ -933,5 +976,4 @@ Status FragmentConsolidator::write_vacuum_file(
   return Status::Ok();
 }
 
-}  // namespace sm
-}  // namespace tiledb
+}  // namespace tiledb::sm
