@@ -47,7 +47,7 @@
 
 #include "tiledb/common/logger.h"
 #include "tiledb/common/unique_rwlock.h"
-#include "tiledb/sm/global_state/global_state.h"
+#include "tiledb/platform/cert_file.h"
 #include "tiledb/sm/global_state/unit_test_config.h"
 #include "tiledb/sm/misc/tdb_math.h"
 #include "tiledb/sm/misc/utils.h"
@@ -275,7 +275,7 @@ Status S3::init(
       "vfs.s3.multipart_part_size", &multipart_part_size_, &found));
   assert(found);
   file_buffer_size_ = multipart_part_size_ * max_parallel_ops_;
-  region_ = config.get("vfs.s3.region", &found);
+  region_ = config.get<std::string>("vfs.s3.region").value_or("");
   assert(found);
   RETURN_NOT_OK(config.get<bool>(
       "vfs.s3.use_virtual_addressing", &use_virtual_addressing_, &found));
@@ -1208,17 +1208,16 @@ Status S3::init_client() const {
       connect_max_tries,
       connect_scale_factor);
 
-#ifdef __linux__
-  // If the user has not set a s3 ca file or ca path then let's attempt to set
-  // the cert file if we've autodetected it
-  if (ca_file.empty() && ca_path.empty()) {
-    const std::string cert_file =
-        global_state::GlobalState::GetGlobalState().cert_file();
-    if (!cert_file.empty()) {
-      client_config.caFile = cert_file.c_str();
+  if constexpr (tiledb::platform::PlatformCertFile::enabled) {
+    // If the user has not set a s3 ca file or ca path then let's attempt to set
+    // the cert file if we've autodetected it
+    if (ca_file.empty() && ca_path.empty()) {
+      const std::string cert_file = tiledb::platform::PlatformCertFile::get();
+      if (!cert_file.empty()) {
+        client_config.caFile = cert_file.c_str();
+      }
     }
   }
-#endif
 
   switch ((!aws_access_key_id.empty() ? 1 : 0) +
           (!aws_secret_access_key.empty() ? 2 : 0) +
