@@ -40,6 +40,7 @@
 #include "tiledb/common/thread_pool.h"
 #include "tiledb/sm/buffer/buffer.h"
 #include "tiledb/sm/config/config.h"
+#include "tiledb/sm/curl/curl_init.h"
 #include "tiledb/sm/filesystem/s3_thread_pool_executor.h"
 #include "tiledb/sm/misc/constants.h"
 #include "tiledb/sm/stats/global_stats.h"
@@ -604,6 +605,13 @@ class S3 {
   /*         PRIVATE ATTRIBUTES        */
   /* ********************************* */
 
+  /**
+   * A libcurl initializer instance. This should remain
+   * the first member variable to ensure that libcurl is
+   * initialized before any calls that may require it.
+   */
+  tiledb::sm::curl::LibCurlInitializer curl_inited_;
+
   /** The class stats. */
   stats::Stats* stats_;
 
