@@ -31,4 +31,4 @@
  */
 
 #define CATCH_CONFIG_MAIN
-#include <catch.hpp>
+#include <test/support/tdb_catch.h>
