@@ -134,6 +134,14 @@ class URI {
    */
   bool is_file() const;
 
+  /**
+   * Checks if the URI contains a string.
+   *
+   * @param str the string to search for in the URI
+   * @return The result of the check.
+   */
+  bool contains(const std::string_view& str) const;
+
   /**
    * Checks if the input path is HDFS.
    *
@@ -253,6 +261,10 @@ class URI {
   /** Returns the last part of the URI (i.e., excluding the parent). */
   std::string last_path_part() const;
 
+  /** Returns the two last parts of the URI (i.e., after the penultimate `/`).
+   */
+  std::string last_two_path_parts() const;
+
   /**
    * Returns the URI path for the current platform, stripping the resource. For
    * example, if "file:///my/path/" is the URI, this function will return
@@ -315,6 +327,19 @@ struct TimestampedURI {
     return timestamp_range_.first < uri.timestamp_range_.first;
   }
 
+  const URI& uri() const {
+    return uri_;
+  }
+
+  const std::pair<uint64_t, uint64_t>& timestamp_range() const {
+    return timestamp_range_;
+  }
+
+  bool operator==(const TimestampedURI& other) const {
+    return (
+        uri() == other.uri() && timestamp_range() == other.timestamp_range());
+  }
+
   bool has_unary_timestamp_range() const {
     return timestamp_range_.first == timestamp_range_.second;
   }
