@@ -502,6 +502,22 @@ Status VFS::remove_file(const URI& uri) const {
       Status_VFSError("Unsupported URI scheme: " + uri.to_string()));
 }
 
+void VFS::remove_files(
+    ThreadPool* compute_tp, const std::vector<URI>& uris) const {
+  throw_if_not_ok(parallel_for(compute_tp, 0, uris.size(), [&](size_t i) {
+    RETURN_NOT_OK(remove_file(uris[i]));
+    return Status::Ok();
+  }));
+}
+
+void VFS::remove_files(
+    ThreadPool* compute_tp, const std::vector<TimestampedURI>& uris) const {
+  throw_if_not_ok(parallel_for(compute_tp, 0, uris.size(), [&](size_t i) {
+    RETURN_NOT_OK(remove_file(uris[i].uri_));
+    return Status::Ok();
+  }));
+}
+
 Status VFS::max_parallel_ops(const URI& uri, uint64_t* ops) const {
   bool found;
   *ops = 0;
