@@ -99,11 +99,12 @@ void BitWidthReductionFilter::dump(FILE* out) const {
 
 Status BitWidthReductionFilter::run_forward(
     const Tile& tile,
-    Tile* const offsets_tile,
+    void* const support_data,
     FilterBuffer* input_metadata,
     FilterBuffer* input,
     FilterBuffer* output_metadata,
     FilterBuffer* output) const {
+  Tile* const offsets_tile = static_cast<Tile*>(support_data);
   auto tile_type = tile.type();
   auto tile_type_size = static_cast<uint8_t>(datatype_size(tile_type));
 
@@ -280,13 +281,14 @@ Status BitWidthReductionFilter::compress_part(
 
 Status BitWidthReductionFilter::run_reverse(
     const Tile& tile,
-    Tile* const offsets_tile,
+    void* support_data,
     FilterBuffer* input_metadata,
     FilterBuffer* input,
     FilterBuffer* output_metadata,
     FilterBuffer* output,
     const Config& config) const {
   (void)config;
+  Tile* offsets_tile = static_cast<Tile*>(support_data);
 
   auto tile_type = tile.type();
   auto tile_type_size = static_cast<uint8_t>(datatype_size(tile_type));
