@@ -94,8 +94,7 @@ class Filter {
    * Implemented by filter subclass.
    *
    * @param tile Current tile on which the filter is being run
-   * @param offsets_tile Offsets tile of the current tile on which the filter is
-   * being run
+   * @param support_data Support data for the filter
    * @param input_metadata Buffer with metadata for `input`
    * @param input Buffer with data to be filtered.
    * @param output_metadata Buffer with metadata for filtered data
@@ -104,7 +103,7 @@ class Filter {
    */
   virtual Status run_forward(
       const Tile& tile,
-      Tile* const offsets_tile,
+      void* const support_data,
       FilterBuffer* input_metadata,
       FilterBuffer* input,
       FilterBuffer* output_metadata,
@@ -120,17 +119,17 @@ class Filter {
    * Implemented by filter subclass.
    *
    * @param tile Current tile on which the filter is being run
-   * @param offsets_tile Offsets tile of the current tile on which the filter is
-   * being run
+   * @param support_data Support data for the filter
    * @param input_metadata Buffer with metadata for `input`
    * @param input Buffer with data to be filtered.
    * @param output_metadata Buffer with metadata for filtered data
    * @param output Buffer with filtered data (unused by in-place filters).
+   * @param config Config object for query-level parameters
    * @return
    */
   virtual Status run_reverse(
       const Tile& tile,
-      Tile* const offsets_tile,
+      void* support_data,
       FilterBuffer* input_metadata,
       FilterBuffer* input,
       FilterBuffer* output_metadata,
