@@ -206,10 +206,7 @@ Status FragmentInfo::get_fragment_name(uint32_t fid, const char** name) const {
     return LOG_STATUS(Status_FragmentInfoError(
         "Cannot get fragment URI; Invalid fragment index"));
 
-  auto meta = single_fragment_info_vec_[fid].meta();
-  auto meta_name =
-      meta->fragment_uri().remove_trailing_slash().last_path_part();
-  *name = meta_name.c_str();
+  *name = single_fragment_info_vec_[fid].name().c_str();
 
   return Status::Ok();
 }
@@ -890,9 +887,7 @@ Status FragmentInfo::load(const ArrayDirectory& array_dir) {
         auto meta = fragment_metadata_value[i];
         if (meta->timestamp_range().first >= timestamp_start_ &&
             meta->timestamp_range().second <= timestamp_end_) {
-          uint64_t size;
-          RETURN_NOT_OK(meta->fragment_size(&size));
-          sizes[i] = size;
+          sizes[i] = meta->fragment_size();
         }
 
         if (preload_rtrees & !meta->dense()) {
@@ -1051,8 +1046,7 @@ tuple<Status, optional<SingleFragmentInfo>> FragmentInfo::load(
   sparse = !meta->dense();
 
   // Get fragment size
-  uint64_t size;
-  RETURN_NOT_OK_TUPLE(meta->fragment_size(&size), nullopt);
+  uint64_t size = meta->fragment_size();
 
   // Compute expanded non-empty domain only for dense fragments
   // Get non-empty domain, and compute expanded non-empty domain
