@@ -35,6 +35,7 @@
 
 #include "tiledb/common/common.h"
 #include "tiledb/common/status.h"
+#include "tiledb/sm/array/array_directory.h"
 #include "tiledb/sm/array_schema/domain.h"
 #include "tiledb/sm/crypto/encryption_key.h"
 #include "tiledb/sm/filesystem/uri.h"
@@ -241,19 +242,9 @@ class FragmentInfo {
   /**
    * Loads the fragment info from an array.
    *
-   * @param set_timestamp_range_from_config If `true` the timestamps
-   *     will be set by reading them from `config_`.
-   * @param set_key_from_cfg If `true`, the encryption key and type
-   *     will be set by reading them from `config_`.
-   * @param compute_anterior If `true`, all fragments
-   *     will be loaded and `anterior_ndrange` will be computed for
-   *     those that have a start timestamp smaller than `timestamp_start_`.
    * @return Status
    */
-  Status load(
-      bool set_timestamp_range_from_config,
-      bool set_key_from_config,
-      bool compute_anterior);
+  Status load();
 
   /**
    * Loads the fragment info from an array using the input key.
@@ -272,6 +263,7 @@ class FragmentInfo {
    * Loads the fragment info from an array using the input key
    * and timestamps.
    *
+   * @param array_dir The array directory to load the fragments.
    * @param timestamp_start This function will load fragments with
    *      whose timestamps are within [timestamp_start, timestamp_end].
    * @param timestamp_end This function will load fragments with
@@ -279,18 +271,15 @@ class FragmentInfo {
    * @param encryption_type The encryption type.
    * @param encryption_key The encryption key.
    * @param key_length The length of `encryption_key`.
-   * @param compute_anterior If `true`, all fragments
-   *     will be loaded and `anterior_ndrange` will be computed for
-   *     those that have a start timestamp smaller than `timestamp_start_`.
    * @return Status
    */
   Status load(
+      const ArrayDirectory& array_dir,
       uint64_t timestamp_start,
       uint64_t timestamp_end,
       EncryptionType encryption_type,
       const void* encryption_key,
-      uint32_t key_length,
-      bool compute_anterior);
+      uint32_t key_length);
 
   /**
    * It replaces a sequence of SingleFragmentInfo elements in
@@ -318,9 +307,63 @@ class FragmentInfo {
   /** Returns the number of fragments to vacuum. */
   uint32_t to_vacuum_num() const;
 
+  /** Returns the list of fragments to vacuum. */
+  inline const std::vector<URI>& to_vacuum() const {
+    return to_vacuum_;
+  }
+
   /** Returns the number of fragments with unconsolidated metadata. */
   uint32_t unconsolidated_metadata_num() const;
 
+  /** Returns array schemas map. */
+  inline const shared_ptr<ArraySchema> array_schema_latest() const {
+    return array_schema_latest_;
+  }
+
+  /** Returns array schemas map. */
+  inline const std::unordered_map<std::string, shared_ptr<ArraySchema>>&
+  array_schemas_all() const {
+    return array_schemas_all_;
+  }
+
+  /** Returns the config. */
+  inline const Config& config() const {
+    return config_;
+  }
+
+  // Accessors
+
+  /** Returns array schemas latest. */
+  inline shared_ptr<ArraySchema>& array_schema_latest() {
+    return array_schema_latest_;
+  }
+
+  /** array_schemas_all accessor. */
+  inline std::unordered_map<std::string, shared_ptr<ArraySchema>>&
+  array_schemas_all() {
+    return array_schemas_all_;
+  }
+
+  /** single_fragment_info_vec_ accessor. */
+  inline std::vector<SingleFragmentInfo>& single_fragment_info_vec() {
+    return single_fragment_info_vec_;
+  }
+
+  /** to_vacuum_ accessor. */
+  inline std::vector<URI>& to_vacuum() {
+    return to_vacuum_;
+  }
+
+  /** array_uri_ accessor. */
+  inline URI& array_uri() {
+    return array_uri_;
+  }
+
+  /** unconsolidated_metadata_num_ accessor. */
+  inline uint32_t& unconsolidated_metadata_num() {
+    return unconsolidated_metadata_num_;
+  }
+
  private:
   /* ********************************* */
   /*         PRIVATE ATTRIBUTES        */
@@ -335,6 +378,9 @@ class FragmentInfo {
   /** The encryption key used if the array is encrypted. */
   EncryptionKey enc_key_;
 
+  /** The latest array schema. */
+  std::shared_ptr<ArraySchema> array_schema_latest_;
+
   /**
    * All the array schemas relevant to the loaded fragment metadata
    * keyed by their file name.
@@ -370,10 +416,14 @@ class FragmentInfo {
   Status set_enc_key_from_config();
 
   /**
-   * Sets the timestamp range from config_. If not present, the timestamp
-   * range is set to [0, now].
+   * Sets the timestamp range to [0, now].
    */
-  Status set_timestamp_range_from_config();
+  Status set_default_timestamp_range();
+
+  /**
+   * Loads the fragment info from an array using the array directory.
+   */
+  Status load(const ArrayDirectory& array_directory);
 
   /**
    * Loads the fragment metadata of the input URI and returns a
