@@ -56,10 +56,21 @@ class CellCmpBase {
   /** The number of dimensions. */
   unsigned dim_num_;
 
+  /** Use timestamps or not during comparison. */
+  bool use_timestamps_;
+
+  /** Pointer to access fragment metadata. */
+  const std::vector<shared_ptr<FragmentMetadata>>* frag_md_;
+
  public:
-  explicit CellCmpBase(const Domain& domain)
+  explicit CellCmpBase(
+      const Domain& domain,
+      const bool use_timestamps = false,
+      const std::vector<shared_ptr<FragmentMetadata>>* frag_md = nullptr)
       : domain_(domain)
-      , dim_num_(domain.dim_num()) {
+      , dim_num_(domain.dim_num())
+      , use_timestamps_(use_timestamps)
+      , frag_md_(frag_md) {
   }
 
   template <class RCType>
@@ -70,6 +81,20 @@ class CellCmpBase {
     auto v2{b.dimension_datum(dim, d)};
     return domain_.cell_order_cmp(d, v1, v2);
   }
+
+  template <class RCType>
+  uint64_t get_timestamp(const RCType& rc) const {
+    const auto f = rc.tile_->frag_idx();
+    if ((*frag_md_)[f]->has_timestamps()) {
+      return rc.tile_->timestamp(rc.pos_);
+    } else {
+      return (*frag_md_)[f]->timestamp_range().first;
+    }
+  }
+
+  inline void use_timestamps(bool enable) {
+    use_timestamps_ = enable;
+  }
 };
 
 /** Wrapper of comparison function for sorting coords on row-major order. */
@@ -136,11 +161,14 @@ class ColCmp : CellCmpBase {
 };
 
 /** Wrapper of comparison function for sorting coords on Hilbert values. */
-class HilbertCmp : protected CellCmpBase {
+class HilbertCmp : public CellCmpBase {
  public:
   /** Constructor. */
-  HilbertCmp(const Domain& domain)
-      : CellCmpBase(domain) {
+  HilbertCmp(
+      const Domain& domain,
+      const bool use_timestamps = false,
+      const std::vector<shared_ptr<FragmentMetadata>>* frag_md = nullptr)
+      : CellCmpBase(domain, use_timestamps, frag_md) {
   }
 
   /**
@@ -172,6 +200,11 @@ class HilbertCmp : protected CellCmpBase {
       // else same tile on dimension d --> continue
     }
 
+    // Compare timestamps
+    if (use_timestamps_ && get_timestamp(a) > get_timestamp(b)) {
+      return true;
+    }
+
     return false;
   }
 };
@@ -186,9 +219,14 @@ class HilbertCmpReverse {
    * Constructor.
    *
    * @param domain The array domain.
+   * @param use_timestamps Use timestamps or not for this comparator.
+   * @param frag_md Pointer to the fragment metadata.
    */
-  HilbertCmpReverse(const Domain& domain)
-      : cmp_(domain) {
+  HilbertCmpReverse(
+      const Domain& domain,
+      const bool use_timestamps = false,
+      const std::vector<shared_ptr<FragmentMetadata>>* frag_md = nullptr)
+      : cmp_(domain, use_timestamps, frag_md) {
   }
 
   /**
@@ -203,6 +241,10 @@ class HilbertCmpReverse {
     return !cmp_.operator()(a, b);
   }
 
+  inline void use_timestamps(bool enable) {
+    cmp_.use_timestamps(enable);
+  }
+
  private:
   /** HilbertCmp. */
   HilbertCmp cmp_;
@@ -264,17 +306,19 @@ class HilbertCmpRCI : protected CellCmpBase {
  * Wrapper of comparison function for sorting coords on the global order
  * of some domain.
  */
-class GlobalCmp : protected CellCmpBase {
+class GlobalCmp : public CellCmpBase {
  public:
   /**
    * Constructor.
    *
    * @param domain The array domain.
-   * @param buff The buffer containing the actual values, used
-   *     in positional comparisons.
+   * @param frag_md Pointer to the fragment metadata.
    */
-  explicit GlobalCmp(const Domain& domain)
-      : CellCmpBase(domain) {
+  explicit GlobalCmp(
+      const Domain& domain,
+      const bool use_timestamps = false,
+      const std::vector<shared_ptr<FragmentMetadata>>* frag_md = nullptr)
+      : CellCmpBase(domain, use_timestamps, frag_md) {
     tile_order_ = domain.tile_order();
     cell_order_ = domain.cell_order();
   }
@@ -343,6 +387,11 @@ class GlobalCmp : protected CellCmpBase {
       }
     }
 
+    // Compare timestamps
+    if (use_timestamps_ && get_timestamp(a) > get_timestamp(b)) {
+      return true;
+    }
+
     return false;
   }
 
@@ -363,11 +412,14 @@ class GlobalCmpReverse {
    * Constructor.
    *
    * @param domain The array domain.
-   * @param buff The buffer containing the actual values, used
-   *     in positional comparisons.
+   * @param use_timestamps Use timestamps or not for this comparator.
+   * @param frag_md Pointer to the fragment metadata.
    */
-  explicit GlobalCmpReverse(const Domain& domain)
-      : cmp_(domain) {
+  explicit GlobalCmpReverse(
+      const Domain& domain,
+      const bool use_timestamps = false,
+      const std::vector<shared_ptr<FragmentMetadata>>* frag_md = nullptr)
+      : cmp_(domain, use_timestamps, frag_md) {
   }
 
   /**
@@ -382,6 +434,10 @@ class GlobalCmpReverse {
     return !cmp_.operator()(a, b);
   }
 
+  inline void use_timestamps(bool enable) {
+    cmp_.use_timestamps(enable);
+  }
+
  private:
   /** GlobalCmp. */
   GlobalCmp cmp_;
