@@ -584,14 +584,14 @@ const std::string hilbert_str = "hilbert";
 /** The string representation of null. */
 const std::string null_str = "null";
 
-/** The string representation of unordered label. */
-const std::string label_unordered_str = "unordered";
+/** The string representation of unordered data. */
+const std::string data_unordered_str = "unordered";
 
-/** The string representation of increasing order label. */
-const std::string label_increasing_str = "increasing";
+/** The string representation of increasing order data. */
+const std::string data_increasing_str = "increasing";
 
-/** The string representation of decreasing order label. */
-const std::string label_decreasing_str = "decreasing";
+/** The string representation of decreasing order data. */
+const std::string data_decreasing_str = "decreasing";
 
 /** The string representation for object type invalid. */
 const std::string object_type_invalid_str = "INVALID";
@@ -637,7 +637,7 @@ const int32_t library_version[3] = {
     TILEDB_VERSION_MAJOR, TILEDB_VERSION_MINOR, TILEDB_VERSION_PATCH};
 
 /** The TileDB serialization base format version number. */
-const format_version_t base_format_version = 16;
+const format_version_t base_format_version = 17;
 
 /**
  * The TileDB serialization format version number.
@@ -808,21 +808,6 @@ const void* fill_value(Datatype type) {
   return nullptr;
 }
 
-#ifdef __linux__
-/** Possible certificate files; stop after finding one.
- * inspired by
- * https://github.com/golang/go/blob/f0e940ebc985661f54d31c8d9ba31a553b87041b/src/crypto/x509/root_linux.go
- */
-const std::array<std::string, 6> cert_files_linux = {
-    "/etc/ssl/certs/ca-certificates.crt",  // Debian/Ubuntu/Gentoo etc.
-    "/etc/pki/tls/certs/ca-bundle.crt",    // Fedora/RHEL 6
-    "/etc/ssl/ca-bundle.pem",              // OpenSUSE
-    "/etc/pki/tls/cacert.pem",             // OpenELEC
-    "/etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem",  // CentOS/RHEL 7
-    "/etc/ssl/cert.pem"                                   // Alpine Linux
-};
-#endif
-
 const std::string config_delimiter = ",";
 }  // namespace constants
 
