@@ -569,14 +569,14 @@ extern const std::string hilbert_str;
 /** The string representation of null. */
 extern const std::string null_str;
 
-/** The string representation of unordered label. */
-extern const std::string label_unordered_str;
+/** The string representation of unordered data. */
+extern const std::string data_unordered_str;
 
-/** The string representation of increasing order label. */
-extern const std::string label_increasing_str;
+/** The string representation of increasing order data. */
+extern const std::string data_increasing_str;
 
-/** The string representation of decreasing order label. */
-extern const std::string label_decreasing_str;
+/** The string representation of decreasing order data. */
+extern const std::string data_decreasing_str;
 
 /** The string representation for object type invalid. */
 extern const std::string object_type_invalid_str;
@@ -687,11 +687,6 @@ const void* fill_value(Datatype type);
 /** The redirection header key in REST response. */
 extern const std::string redirection_header_key;
 
-#ifdef __linux__
-/** List of possible certificates files for libcurl */
-extern const std::array<std::string, 6> cert_files_linux;
-#endif
-
 /** Delimiter for lists passed as config parameter */
 extern const std::string config_delimiter;
 
