@@ -289,7 +289,8 @@ Status Reader::load_initial_data() {
   user_requested_timestamps_ = buffers_.count(constants::timestamps) != 0 ||
                                delete_and_update_conditions_.size() > 0;
   const bool partial_consol_fragment_overlap =
-      partial_consolidated_fragment_overlap();
+      partial_consolidated_fragment_overlap(
+          read_state_.partitioner_.subarray());
   use_timestamps_ = partial_consol_fragment_overlap ||
                     !array_schema_.allows_dups() || user_requested_timestamps_;
 
@@ -1411,11 +1412,12 @@ Status Reader::process_tiles(
 
   // Pre-load all attribute offsets into memory for attributes
   // to be read.
-  RETURN_NOT_OK(load_tile_offsets(subarray, read_names));
+  RETURN_NOT_OK(load_tile_offsets(subarray.relevant_fragments(), read_names));
 
   // Pre-load all var attribute var tile sizes into memory for attributes
   // to be read.
-  RETURN_NOT_OK(load_tile_var_sizes(subarray, var_size_read_names));
+  RETURN_NOT_OK(
+      load_tile_var_sizes(subarray.relevant_fragments(), var_size_read_names));
 
   // Get the maximum number of attributes to read and unfilter in parallel.
   // Each attribute requires additional memory to buffer reads into
@@ -1637,7 +1639,8 @@ Status Reader::compute_result_coords(
   auto& subarray = read_state_.partitioner_.current();
   std::vector<std::string> zipped_coords_names = {constants::coords};
   RETURN_CANCEL_OR_ERROR(load_tile_offsets(
-      read_state_.partitioner_.subarray(), zipped_coords_names));
+      read_state_.partitioner_.subarray().relevant_fragments(),
+      zipped_coords_names));
 
   // Preload unzipped coordinate tile offsets. Note that this will
   // ignore fragments with a version < 5.
@@ -1651,10 +1654,11 @@ Status Reader::compute_result_coords(
     if (array_schema_.var_size(name))
       var_size_dim_names.emplace_back(name);
   }
-  RETURN_CANCEL_OR_ERROR(
-      load_tile_offsets(read_state_.partitioner_.subarray(), dim_names));
+  RETURN_CANCEL_OR_ERROR(load_tile_offsets(
+      read_state_.partitioner_.subarray().relevant_fragments(), dim_names));
   RETURN_CANCEL_OR_ERROR(load_tile_var_sizes(
-      read_state_.partitioner_.subarray(), var_size_dim_names));
+      read_state_.partitioner_.subarray().relevant_fragments(),
+      var_size_dim_names));
 
   // Read and unfilter zipped coordinate tiles. Note that
   // this will ignore fragments with a version >= 5.
@@ -1675,7 +1679,8 @@ Status Reader::compute_result_coords(
   if (bitsort_attr.has_value()) {
     std::vector<std::string> bitsort_attr_name = {bitsort_attr.value()};
     RETURN_CANCEL_OR_ERROR(load_tile_offsets(
-        read_state_.partitioner_.subarray(), bitsort_attr_name));
+        read_state_.partitioner_.subarray().relevant_fragments(),
+        bitsort_attr_name));
     RETURN_CANCEL_OR_ERROR(
         read_attribute_tiles(bitsort_attr_name, tmp_result_tiles));
     RETURN_CANCEL_OR_ERROR(
@@ -1685,8 +1690,8 @@ Status Reader::compute_result_coords(
   // Read and unfilter timestamps, if required.
   if (use_timestamps_) {
     std::vector<std::string> timestamps = {constants::timestamps};
-    RETURN_CANCEL_OR_ERROR(
-        load_tile_offsets(read_state_.partitioner_.subarray(), timestamps));
+    RETURN_CANCEL_OR_ERROR(load_tile_offsets(
+        read_state_.partitioner_.subarray().relevant_fragments(), timestamps));
 
     RETURN_CANCEL_OR_ERROR(read_attribute_tiles(timestamps, tmp_result_tiles));
     RETURN_CANCEL_OR_ERROR(
@@ -1697,7 +1702,8 @@ Status Reader::compute_result_coords(
   {
     std::vector<std::string> delete_timestamps = {constants::delete_timestamps};
     RETURN_CANCEL_OR_ERROR(load_tile_offsets(
-        read_state_.partitioner_.subarray(), delete_timestamps));
+        read_state_.partitioner_.subarray().relevant_fragments(),
+        delete_timestamps));
 
     RETURN_CANCEL_OR_ERROR(
         read_attribute_tiles(delete_timestamps, tmp_result_tiles));
