@@ -66,6 +66,14 @@ using namespace tiledb::sm::stats;
 namespace tiledb {
 namespace sm {
 
+/** Class for query status exceptions. */
+class QueryStatusException : public StatusException {
+ public:
+  explicit QueryStatusException(const std::string& msg)
+      : StatusException("Query", msg) {
+  }
+};
+
 /* ****************************** */
 /*   CONSTRUCTORS & DESTRUCTORS   */
 /* ****************************** */
@@ -139,257 +147,6 @@ Query::~Query() {
 /*               API              */
 /* ****************************** */
 
-Status Query::add_range(
-    unsigned dim_idx, const void* start, const void* end, const void* stride) {
-  if (type_ != QueryType::READ && type_ != QueryType::WRITE &&
-      type_ != QueryType::MODIFY_EXCLUSIVE) {
-    return logger_->status(
-        Status_QueryError("Adding a range for an unsupported query type"));
-  }
-
-  if (dim_idx >= array_schema_->dim_num()) {
-    return logger_->status(
-        Status_QueryError("Cannot add range; Invalid dimension index"));
-  }
-
-  if (start == nullptr || end == nullptr) {
-    return logger_->status(
-        Status_QueryError("Cannot add range; Invalid range"));
-  }
-
-  if (stride != nullptr) {
-    return logger_->status(Status_QueryError(
-        "Cannot add range; Setting range stride is currently unsupported"));
-  }
-
-  if (array_schema_->domain().dimension_ptr(dim_idx)->var_size()) {
-    return logger_->status(
-        Status_QueryError("Cannot add range; Range must be fixed-sized"));
-  }
-
-  // Prepare a temp range
-  std::vector<uint8_t> range;
-  auto coord_size{array_schema_->dimension_ptr(dim_idx)->coord_size()};
-  range.resize(2 * coord_size);
-  std::memcpy(&range[0], start, coord_size);
-  std::memcpy(&range[coord_size], end, coord_size);
-
-  bool read_range_oob_error = true;
-  if (type_ == QueryType::READ) {
-    // Get read_range_oob config setting
-    bool found = false;
-    std::string read_range_oob = config_.get("sm.read_range_oob", &found);
-    assert(found);
-
-    if (read_range_oob != "error" && read_range_oob != "warn")
-      return logger_->status(Status_QueryError(
-          "Invalid value " + read_range_oob +
-          " for sm.read_range_obb. Acceptable values are 'error' or "
-          "'warn'."));
-
-    read_range_oob_error = read_range_oob == "error";
-  } else {
-    if (!array_schema_->dense())
-      return logger_->status(
-          Status_QueryError("Adding a subarray range to a write query is not "
-                            "supported in sparse arrays"));
-
-    if (subarray_.is_set(dim_idx))
-      return logger_->status(
-          Status_QueryError("Cannot add range; Multi-range dense writes "
-                            "are not supported"));
-  }
-
-  // Add range
-  Range r(&range[0], 2 * coord_size);
-  return subarray_.add_range(dim_idx, std::move(r), read_range_oob_error);
-}
-
-Status Query::add_range_var(
-    unsigned dim_idx,
-    const void* start,
-    uint64_t start_size,
-    const void* end,
-    uint64_t end_size) {
-  if (type_ != QueryType::READ && type_ != QueryType::WRITE &&
-      type_ != QueryType::MODIFY_EXCLUSIVE) {
-    return logger_->status(
-        Status_QueryError("Adding a range for an unsupported query type"));
-  }
-
-  if (dim_idx >= array_schema_->dim_num())
-    return logger_->status(
-        Status_QueryError("Cannot add range; Invalid dimension index"));
-
-  if ((start == nullptr && start_size != 0) ||
-      (end == nullptr && end_size != 0))
-    return logger_->status(
-        Status_QueryError("Cannot add range; Invalid range"));
-
-  if (!array_schema_->domain().dimension_ptr(dim_idx)->var_size())
-    return logger_->status(
-        Status_QueryError("Cannot add range; Range must be variable-sized"));
-
-  if (type_ == QueryType::WRITE || type_ == QueryType::MODIFY_EXCLUSIVE)
-    return logger_->status(Status_QueryError(
-        "Cannot add range; Function applicable only to reads"));
-
-  // Get read_range_oob config setting
-  bool found = false;
-  std::string read_range_oob = config_.get("sm.read_range_oob", &found);
-  assert(found);
-
-  if (read_range_oob != "error" && read_range_oob != "warn")
-    return logger_->status(Status_QueryError(
-        "Invalid value " + read_range_oob +
-        " for sm.read_range_obb. Acceptable values are 'error' or 'warn'."));
-
-  // Add range
-  Range r{start, start_size, end, end_size};
-  return subarray_.add_range(dim_idx, std::move(r), read_range_oob == "error");
-}
-
-Status Query::get_range_num(unsigned dim_idx, uint64_t* range_num) const {
-  if ((type_ == QueryType::WRITE || type_ == QueryType::MODIFY_EXCLUSIVE) &&
-      !array_schema_->dense())
-    return logger_->status(
-        Status_QueryError("Getting the number of ranges from a write query "
-                          "is not applicable to sparse arrays"));
-
-  return subarray_.get_range_num(dim_idx, range_num);
-}
-
-Status Query::get_range(
-    unsigned dim_idx,
-    uint64_t range_idx,
-    const void** start,
-    const void** end,
-    const void** stride) const {
-  if (type_ != QueryType::READ) {
-    return logger_->status(Status_QueryError(
-        "Getting a var range size only applicable to read queries"));
-  }
-
-  if ((type_ == QueryType::WRITE || type_ == QueryType::MODIFY_EXCLUSIVE) &&
-      !array_schema_->dense()) {
-    return logger_->status(
-        Status_QueryError("Getting a range from a write query is not "
-                          "applicable to sparse arrays"));
-  }
-
-  *stride = nullptr;
-  return subarray_.get_range(dim_idx, range_idx, start, end);
-}
-
-Status Query::get_range_var_size(
-    unsigned dim_idx,
-    uint64_t range_idx,
-    uint64_t* start_size,
-    uint64_t* end_size) const {
-  if (type_ != QueryType::READ) {
-    return logger_->status(Status_QueryError(
-        "Getting a var range size only applicable to read queries"));
-  }
-
-  return subarray_.get_range_var_size(dim_idx, range_idx, start_size, end_size);
-  ;
-}
-
-Status Query::get_range_var(
-    unsigned dim_idx, uint64_t range_idx, void* start, void* end) const {
-  if (type_ != QueryType::READ) {
-    return logger_->status(Status_QueryError(
-        "Getting a var range only applicable to read queries"));
-  }
-
-  uint64_t start_size = 0;
-  uint64_t end_size = 0;
-  throw_if_not_ok(
-      subarray_.get_range_var_size(dim_idx, range_idx, &start_size, &end_size));
-
-  const void* range_start;
-  const void* range_end;
-  const void* stride;
-  RETURN_NOT_OK(
-      get_range(dim_idx, range_idx, &range_start, &range_end, &stride));
-
-  std::memcpy(start, range_start, start_size);
-  std::memcpy(end, range_end, end_size);
-
-  return Status::Ok();
-}
-
-Status Query::add_range_by_name(
-    const std::string& dim_name,
-    const void* start,
-    const void* end,
-    const void* stride) {
-  unsigned dim_idx;
-  RETURN_NOT_OK(
-      array_schema_->domain().get_dimension_index(dim_name, &dim_idx));
-
-  return add_range(dim_idx, start, end, stride);
-}
-
-Status Query::add_range_var_by_name(
-    const std::string& dim_name,
-    const void* start,
-    uint64_t start_size,
-    const void* end,
-    uint64_t end_size) {
-  unsigned dim_idx;
-  RETURN_NOT_OK(
-      array_schema_->domain().get_dimension_index(dim_name, &dim_idx));
-
-  return add_range_var(dim_idx, start, start_size, end, end_size);
-}
-
-Status Query::get_range_num_from_name(
-    const std::string& dim_name, uint64_t* range_num) const {
-  unsigned dim_idx;
-  RETURN_NOT_OK(
-      array_schema_->domain().get_dimension_index(dim_name, &dim_idx));
-
-  return get_range_num(dim_idx, range_num);
-}
-
-Status Query::get_range_from_name(
-    const std::string& dim_name,
-    uint64_t range_idx,
-    const void** start,
-    const void** end,
-    const void** stride) const {
-  unsigned dim_idx;
-  RETURN_NOT_OK(
-      array_schema_->domain().get_dimension_index(dim_name, &dim_idx));
-
-  return get_range(dim_idx, range_idx, start, end, stride);
-}
-
-Status Query::get_range_var_size_from_name(
-    const std::string& dim_name,
-    uint64_t range_idx,
-    uint64_t* start_size,
-    uint64_t* end_size) const {
-  unsigned dim_idx;
-  RETURN_NOT_OK(
-      array_schema_->domain().get_dimension_index(dim_name, &dim_idx));
-
-  return get_range_var_size(dim_idx, range_idx, start_size, end_size);
-}
-
-Status Query::get_range_var_from_name(
-    const std::string& dim_name,
-    uint64_t range_idx,
-    void* start,
-    void* end) const {
-  unsigned dim_idx;
-  RETURN_NOT_OK(
-      array_schema_->domain().get_dimension_index(dim_name, &dim_idx));
-
-  return get_range_var(dim_idx, range_idx, start, end);
-}
-
 Status Query::get_est_result_size(const char* name, uint64_t* size) {
   if (type_ != QueryType::READ) {
     return logger_->status(Status_QueryError(
@@ -896,6 +653,16 @@ Status Query::get_offsets_buffer(
     return Status::Ok();
   }
 
+  // Dimension label
+  if constexpr (is_experimental_build) {
+    auto it = label_buffers_.find(name);
+    if (it != label_buffers_.end()) {
+      *buffer_off = (uint64_t*)it->second.buffer_;
+      *buffer_off_size = it->second.buffer_size_;
+      return Status::Ok();
+    }
+  }
+
   // Named buffer does not exist
   *buffer_off = nullptr;
   *buffer_off_size = nullptr;
@@ -942,6 +709,21 @@ Status Query::get_data_buffer(
     return Status::Ok();
   }
 
+  if constexpr (is_experimental_build) {
+    // Return the buffer
+    auto it = label_buffers_.find(name);
+    if (it != label_buffers_.end()) {
+      if (array_schema_->dimension_label_reference(name).is_var()) {
+        *buffer = it->second.buffer_var_;
+        *buffer_size = it->second.buffer_var_size_;
+      } else {
+        *buffer = it->second.buffer_;
+        *buffer_size = it->second.buffer_size_;
+      }
+      return Status::Ok();
+    }
+  }
+
   // Named buffer does not exist
   *buffer = nullptr;
   *buffer_size = nullptr;
@@ -949,76 +731,6 @@ Status Query::get_data_buffer(
   return Status::Ok();
 }
 
-void Query::get_label_data_buffer(
-    const std::string& name, void** buffer, uint64_t** buffer_size) const {
-  // Check query type
-  if (type_ != QueryType::READ && type_ != QueryType::WRITE) {
-    throw StatusException(
-        Status_QueryError("Cannot get buffer; Unsupported query type."));
-  }
-
-  // Check that dimension label exists
-  if (!array_schema_->is_dim_label(name)) {
-    throw StatusException(Status_QueryError(
-        std::string("Cannot set buffer; Invalid dimension label '") + name +
-        "'"));
-  }
-
-  // Return the buffer
-  auto it = label_buffers_.find(name);
-  if (it != label_buffers_.end()) {
-    if (array_schema_->dimension_label_reference(name).is_var()) {
-      *buffer = it->second.buffer_var_;
-      *buffer_size = it->second.buffer_var_size_;
-    } else {
-      *buffer = it->second.buffer_;
-      *buffer_size = it->second.buffer_size_;
-    }
-    return;
-  }
-
-  // Named buffer does not exist
-  *buffer = nullptr;
-  *buffer_size = nullptr;
-}
-
-void Query::get_label_offsets_buffer(
-    const std::string& name,
-    uint64_t** buffer_off,
-    uint64_t** buffer_off_size) const {
-  // Check query type
-  if (type_ != QueryType::READ && type_ != QueryType::WRITE) {
-    throw StatusException(Status_SerializationError(
-        "Cannot get buffer; Unsupported query type."));
-  }
-
-  // Check that dimension label exists
-  if (!array_schema_->is_dim_label(name)) {
-    throw StatusException(Status_QueryError(
-        std::string("Cannot set buffer; Invalid dimension label '") + name +
-        "'"));
-  }
-
-  // Error if it is fixed-sized
-  if (!array_schema_->dimension_label_reference(name).is_var()) {
-    throw StatusException(Status_QueryError(
-        std::string("Cannot set buffer; Input attribute/dimension '") + name +
-        "' is fixed-sized"));
-  }
-
-  // Attribute or dimension
-  auto it = label_buffers_.find(name);
-  if (it != label_buffers_.end()) {
-    *buffer_off = (uint64_t*)it->second.buffer_;
-    *buffer_off_size = it->second.buffer_size_;
-    return;
-  }
-
-  // Named buffer does not exist
-  *buffer_off = nullptr;
-  *buffer_off_size = nullptr;
-}
-
 Status Query::get_validity_buffer(
     const char* name,
     uint8_t** buffer_validity_bytemap,
@@ -1241,7 +953,6 @@ Status Query::init() {
       dim_label_queries_ = tdb_unique_ptr<ArrayDimensionLabelQueries>(tdb_new(
           ArrayDimensionLabelQueries,
           storage_manager_,
-          stats_->create_child("ArrayDimensionLabelQueries"),
           array_,
           subarray_,
           label_buffers_,
@@ -1835,6 +1546,7 @@ Status Query::set_data_buffer(
     void* const buffer,
     uint64_t* const buffer_size,
     const bool check_null_buffers) {
+  // General checks for fixed buffers
   RETURN_NOT_OK(check_set_fixed_buffer(name));
 
   // Check buffer
@@ -1852,15 +1564,43 @@ Status Query::set_data_buffer(
         "Cannot set buffer; " + name + " buffer size is null"));
   }
 
+  // If this is for a dimension label, set the dimension label buffer and
+  // return.
+  if constexpr (is_experimental_build) {
+    if (array_schema_->is_dim_label(name)) {
+      // Check the query type is valid.
+      if (type_ != QueryType::READ && type_ != QueryType::WRITE) {
+        throw StatusException(Status_SerializationError(
+            "Cannot set buffer; Unsupported query type."));
+      }
+
+      // Set dimension label buffer on the appropriate buffer depending if the
+      // label is fixed or variable length.
+      array_schema_->dimension_label_reference(name).is_var() ?
+          throw_if_not_ok(
+              label_buffers_[name].set_data_var_buffer(buffer, buffer_size)) :
+          throw_if_not_ok(
+              label_buffers_[name].set_data_buffer(buffer, buffer_size));
+      return Status::Ok();
+    }
+  }
+
   // For easy reference
   const bool is_dim = array_schema_->is_dim(name);
   const bool is_attr = array_schema_->is_attr(name);
 
   // Check that attribute/dimension exists
   if (!ArraySchema::is_special_attribute(name) && !is_dim && !is_attr) {
-    return logger_->status(Status_QueryError(
-        std::string("Cannot set buffer; Invalid attribute/dimension '") + name +
-        "'"));
+    if constexpr (is_experimental_build) {
+      return logger_->status(Status_QueryError(
+          std::string(
+              "Cannot set buffer; Invalid attribute/dimension/label '") +
+          name + "'"));
+    } else {
+      return logger_->status(Status_QueryError(
+          std::string("Cannot set buffer; Invalid attribute/dimension '") +
+          name + "'"));
+    }
   }
 
   if (array_schema_->dense() &&
@@ -1925,103 +1665,6 @@ Status Query::set_data_buffer(
   return Status::Ok();
 }
 
-void Query::set_label_data_buffer(
-    const std::string& name,
-    void* const buffer,
-    uint64_t* const buffer_size,
-    const bool check_null_buffers) {
-  // Check the query type is valid.
-  if (type_ != QueryType::READ && type_ != QueryType::WRITE) {
-    throw StatusException(Status_SerializationError(
-        "Cannot set buffer; Unsupported query type."));
-  }
-
-  // Check buffer and buffer size.
-  if (check_null_buffers) {
-    if (buffer == nullptr && (type_ != QueryType::WRITE || *buffer_size != 0)) {
-      throw StatusException(
-          Status_QueryError("Cannot set buffer; " + name + " buffer is null"));
-    }
-    if (buffer_size == nullptr) {
-      throw StatusException(Status_QueryError(
-          "Cannot set buffer; " + name + " buffer size is null"));
-    }
-  }
-
-  // Check that dimension label exists.
-  if (!array_schema_->is_dim_label(name)) {
-    throw StatusException(Status_QueryError(
-        std::string("Cannot set buffer; Invalid dimension label '") + name +
-        "'"));
-  }
-
-  // Error if setting a new dimension label after initialization.
-  if (status_ != QueryStatus::UNINITIALIZED) {
-    throw StatusException(Status_QueryError(
-        std::string("Cannot set buffer for new dimension label '") + name +
-        "' after initialization"));
-  }
-
-  // Set dimension label buffer on the appropriate buffer depending if the label
-  // is fixed or variable length.
-  array_schema_->dimension_label_reference(name).is_var() ?
-      throw_if_not_ok(
-          label_buffers_[name].set_data_var_buffer(buffer, buffer_size)) :
-      throw_if_not_ok(
-          label_buffers_[name].set_data_buffer(buffer, buffer_size));
-}
-
-void Query::set_label_offsets_buffer(
-    const std::string& name,
-    uint64_t* const buffer_offsets,
-    uint64_t* const buffer_offsets_size,
-    const bool check_null_buffers) {
-  // Check the query type is valid.
-  if (type_ != QueryType::READ && type_ != QueryType::WRITE) {
-    throw StatusException(Status_SerializationError(
-        "Cannot set buffer; Unsupported query type."));
-  }
-
-  // Check for nullptrs.
-  if (check_null_buffers) {
-    if (buffer_offsets == nullptr) {
-      throw StatusException(
-          Status_QueryError("Cannot set buffer; " + name + " buffer is null"));
-    }
-
-    // Check buffer size
-    if (buffer_offsets_size == nullptr) {
-      throw StatusException(Status_QueryError(
-          "Cannot set buffer; " + name + " buffer size is null"));
-    }
-  }
-
-  // Check that dimension label exists.
-  if (!array_schema_->is_dim_label(name)) {
-    throw StatusException(Status_QueryError(
-        std::string("Cannot set buffer; Invalid dimension label '") + name +
-        "'"));
-  }
-
-  // Check the dimension labe is in fact variable length.
-  if (!array_schema_->dimension_label_reference(name).is_var()) {
-    throw StatusException(Status_QueryError(
-        std::string("Cannot set buffer; Input attribute/dimension '") + name +
-        "' is fixed-sized"));
-  }
-
-  // Check the query was not already initialized.
-  if (status_ != QueryStatus::UNINITIALIZED) {
-    throw StatusException(Status_QueryError(
-        std::string("Cannot set buffer for new attribute/dimension '") + name +
-        "' after initialization"));
-  }
-
-  // Set dimension label offsets buffers.
-  throw_if_not_ok(label_buffers_[name].set_offsets_buffer(
-      buffer_offsets, buffer_offsets_size));
-}
-
 Status Query::set_offsets_buffer(
     const std::string& name,
     uint64_t* const buffer_offsets,
@@ -2039,15 +1682,53 @@ Status Query::set_offsets_buffer(
     return logger_->status(Status_QueryError(
         "Cannot set buffer; " + name + " buffer size is null"));
 
+  // If this is for a dimension label, set the dimension label offsets buffer
+  // and return.
+  if constexpr (is_experimental_build) {
+    if (array_schema_->is_dim_label(name)) {
+      // Check the query type is valid.
+      if (type_ != QueryType::READ && type_ != QueryType::WRITE) {
+        throw StatusException(Status_SerializationError(
+            "Cannot set buffer; Unsupported query type."));
+      }
+
+      // Check the dimension labe is in fact variable length.
+      if (!array_schema_->dimension_label_reference(name).is_var()) {
+        throw StatusException(Status_QueryError(
+            std::string("Cannot set buffer; Input dimension label '") + name +
+            "' is fixed-sized"));
+      }
+
+      // Check the query was not already initialized.
+      if (status_ != QueryStatus::UNINITIALIZED) {
+        throw StatusException(Status_QueryError(
+            std::string("Cannot set buffer for new dimension label '") + name +
+            "' after initialization"));
+      }
+
+      // Set dimension label offsets buffers.
+      throw_if_not_ok(label_buffers_[name].set_offsets_buffer(
+          buffer_offsets, buffer_offsets_size));
+      return Status::Ok();
+    }
+  }
+
   // For easy reference
   const bool is_dim = array_schema_->is_dim(name);
   const bool is_attr = array_schema_->is_attr(name);
 
   // Neither a dimension nor an attribute
-  if (!is_dim && !is_attr)
-    return logger_->status(Status_QueryError(
-        std::string("Cannot set buffer; Invalid buffer name '") + name +
-        "' (it should be an attribute or dimension)"));
+  if (!is_dim && !is_attr) {
+    if constexpr (is_experimental_build) {
+      return logger_->status(Status_QueryError(
+          std::string("Cannot set buffer; Invalid buffer name '") + name +
+          "' (it should be an attribute, dimension, or dimension label)"));
+    } else {
+      return logger_->status(Status_QueryError(
+          std::string("Cannot set buffer; Invalid buffer name '") + name +
+          "' (it should be an attribute or dimension)"));
+    }
+  }
 
   // Error if it is fixed-sized
   if (!array_schema_->var_size(name))
@@ -2515,78 +2196,38 @@ void Query::set_status(QueryStatus status) {
   status_ = status;
 }
 
-Status Query::set_subarray(const void* subarray) {
-  if (type_ != QueryType::READ && type_ != QueryType::WRITE &&
-      type_ != QueryType::MODIFY_EXCLUSIVE) {
-    return LOG_STATUS(Status_SerializationError(
-        "Cannot set subarray; Unsupported query type."));
+void Query::set_subarray(const void* subarray) {
+  // Perform checks related to the query type.
+  switch (type_) {
+    case QueryType::READ:
+      break;
+
+    case QueryType::WRITE:
+    case QueryType::MODIFY_EXCLUSIVE:
+      if (!array_schema_->dense()) {
+        throw QueryStatusException(
+            "Cannot set subarray; Setting a subarray is not supported on "
+            "sparse writes.");
+      }
+      break;
+
+    default:
+
+      throw QueryStatusException(
+          "Cannot set subarray; Setting a subarray is not supported for query "
+          "type '" +
+          query_type_str(type_) + "'.");
   }
 
-  if (!array_schema_->domain().all_dims_same_type())
-    return logger_->status(
-        Status_QueryError("Cannot set subarray; Function not applicable to "
-                          "heterogeneous domains"));
-
-  if (!array_schema_->domain().all_dims_fixed())
-    return logger_->status(
-        Status_QueryError("Cannot set subarray; Function not applicable to "
-                          "domains with variable-sized dimensions"));
-
-  // Prepare a subarray object
-  Subarray sub(array_, layout_, stats_, logger_);
-  if (subarray != nullptr) {
-    auto dim_num = array_schema_->dim_num();
-    auto s_ptr = (const unsigned char*)subarray;
-    uint64_t offset = 0;
-
-    bool err_on_range_oob = true;
-    if (type_ == QueryType::READ) {
-      // Get read_range_oob config setting
-      bool found = false;
-      std::string read_range_oob_str =
-          config().get("sm.read_range_oob", &found);
-      assert(found);
-      if (read_range_oob_str != "error" && read_range_oob_str != "warn")
-        return logger_->status(Status_QueryError(
-            "Invalid value " + read_range_oob_str +
-            " for sm.read_range_obb. Acceptable values are 'error' or "
-            "'warn'."));
-      err_on_range_oob = read_range_oob_str == "error";
-    }
-
-    for (unsigned d = 0; d < dim_num; ++d) {
-      auto r_size{2 * array_schema_->dimension_ptr(d)->coord_size()};
-      Range range(&s_ptr[offset], r_size);
-      RETURN_NOT_OK(sub.add_range(d, std::move(range), err_on_range_oob));
-      offset += r_size;
-    }
+  // Check this isn't an already initialized query using dimension labels.
+  if (status_ != QueryStatus::UNINITIALIZED) {
+    throw QueryStatusException(
+        "Cannot set subarray; Setting a subarray on an already initialized  "
+        "query is not supported.");
   }
 
-  if (type_ == QueryType::WRITE || type_ == QueryType::MODIFY_EXCLUSIVE) {
-    // Not applicable to sparse arrays
-    if (!array_schema_->dense())
-      return logger_->status(Status_WriterError(
-          "Setting a subarray is not supported in sparse writes"));
-
-    // Subarray must be unary for dense writes
-    if (sub.range_num() != 1)
-      return logger_->status(
-          Status_WriterError("Cannot set subarray; Multi-range dense writes "
-                             "are not supported"));
-
-    // When executed from serialization, resetting the strategy will delete
-    // the fragment for global order writes. We need to prevent this, thus
-    // persist the fragment between remote global order write submits.
-    if (strategy_ != nullptr && layout_ != Layout::GLOBAL_ORDER) {
-      strategy_->reset();
-    }
-  }
-
-  subarray_ = sub;
-
-  status_ = QueryStatus::UNINITIALIZED;
-
-  return Status::Ok();
+  // Set the subarray.
+  throw_if_not_ok(subarray_.set_subarray(subarray));
 }
 
 const Subarray* Query::subarray() const {
@@ -2598,24 +2239,39 @@ Status Query::set_subarray_unsafe(const Subarray& subarray) {
   return Status::Ok();
 }
 
-Status Query::set_subarray(const tiledb::sm::Subarray& subarray) {
-  auto query_status = status();
-  if (query_status != tiledb::sm::QueryStatus::UNINITIALIZED &&
-      query_status != tiledb::sm::QueryStatus::COMPLETED) {
-    // Can be in this initialized state when query has been de-serialized
-    // server-side and are trying to perform local submit.
-    // Don't change anything and return indication of success.
-    return Status::Ok();
+void Query::set_subarray(const tiledb::sm::Subarray& subarray) {
+  // Perform checks related to the query type.
+  switch (type_) {
+    case QueryType::READ:
+      break;
+
+    case QueryType::WRITE:
+    case QueryType::MODIFY_EXCLUSIVE:
+      if (!array_schema_->dense()) {
+        throw QueryStatusException(
+            "Cannot set subarray; Setting a subarray is not supported on "
+            "sparse writes.");
+      }
+      break;
+
+    default:
+      throw QueryStatusException(
+          "Cannot set subarray; Setting a subarray is not supported for query "
+          "type '" +
+          query_type_str(type_) + "'.");
   }
 
-  // Set subarray
+  // Check the query has not been initialized.
+  if (status_ != tiledb::sm::QueryStatus::UNINITIALIZED) {
+    throw QueryStatusException(
+        "Cannot set subarray; Setting a subarray on an already initialized "
+        "query is not supported.");
+  }
+
+  // Set the subarray.
   auto prev_layout = subarray_.layout();
   subarray_ = subarray;
   subarray_.set_layout(prev_layout);
-
-  status_ = QueryStatus::UNINITIALIZED;
-
-  return Status::Ok();
 }
 
 Status Query::set_subarray_unsafe(const NDRange& subarray) {
@@ -2630,11 +2286,13 @@ Status Query::set_subarray_unsafe(const NDRange& subarray) {
   assert(layout_ == sub.layout());
   subarray_ = sub;
 
-  status_ = QueryStatus::UNINITIALIZED;
-
   return Status::Ok();
 }
 
+void Query::set_subarray_unsafe(const void* subarray) {
+  subarray_.set_subarray_unsafe(subarray);
+}
+
 Status Query::check_buffers_correctness() {
   ensure_query_type_is_valid(type_);
 
