@@ -48,6 +48,7 @@
 #include "tiledb/sm/query/legacy/cell_slab_iter.h"
 #include "tiledb/sm/query/query_buffer.h"
 #include "tiledb/sm/query/query_macros.h"
+#include "tiledb/sm/query/readers/attribute_order_validator.h"
 #include "tiledb/sm/query/strategy_base.h"
 #include "tiledb/sm/query/writers/domain_buffer.h"
 #include "tiledb/sm/subarray/subarray.h"
@@ -115,6 +116,12 @@ ReaderBase::ReaderBase(
     fragment_metadata_ = array->fragment_metadata();
   timestamps_needed_for_deletes_and_updates_.resize(fragment_metadata_.size());
 
+  if (layout_ == Layout::GLOBAL_ORDER && subarray.range_num() > 1) {
+    throw ReaderBaseStatusException(
+        "Cannot initialize reader; Multi-range reads are not supported on a "
+        "global order query.");
+  }
+
   bool found = false;
   if (!config_.get<bool>("vfs.disable_batching", &disable_batching_, &found)
            .ok()) {
@@ -330,14 +337,10 @@ void ReaderBase::check_validity_buffer_sizes() const {
   }
 }
 
-bool ReaderBase::partial_consolidated_fragment_overlap() const {
+bool ReaderBase::partial_consolidated_fragment_overlap(
+    Subarray& subarray) const {
   // Fetch relevant fragments so we check only intersecting fragments
-  const auto relevant_fragments = subarray_.relevant_fragments();
-  bool all_frag = !subarray_.is_set();
-  for (size_t i = 0;
-       i < (all_frag ? fragment_metadata_.size() : relevant_fragments->size());
-       i++) {
-    auto frag_idx = all_frag ? i : relevant_fragments->at(i);
+  for (const auto frag_idx : subarray.relevant_fragments()) {
     auto& fragment = fragment_metadata_[frag_idx];
     if (fragment->has_timestamps() &&
         fragment->partial_time_overlap(
@@ -410,22 +413,17 @@ bool ReaderBase::include_timestamps(const unsigned f) const {
 }
 
 Status ReaderBase::load_tile_offsets(
-    Subarray& subarray, const std::vector<std::string>& names) {
+    const RelevantFragments& relevant_fragments,
+    const std::vector<std::string>& names) {
   auto timer_se = stats_->start_timer("load_tile_offsets");
   const auto encryption_key = array_->encryption_key();
 
-  // Fetch relevant fragments so we load tile offsets only from intersecting
-  // fragments
-  const auto relevant_fragments = subarray.relevant_fragments();
-
-  bool all_frag = !subarray.is_set();
-
   const auto status = parallel_for(
       storage_manager_->compute_tp(),
       0,
-      all_frag ? fragment_metadata_.size() : relevant_fragments->size(),
+      relevant_fragments.size(),
       [&](const uint64_t i) {
-        auto frag_idx = all_frag ? i : relevant_fragments->at(i);
+        auto frag_idx = relevant_fragments[i];
         auto& fragment = fragment_metadata_[frag_idx];
         const auto format_version = fragment->format_version();
 
@@ -445,8 +443,8 @@ Status ReaderBase::load_tile_offsets(
             continue;
           }
 
-          // Not a member of array schema, this field was added in array schema
-          // evolution, ignore for this fragment's tile offsets
+          // Not a member of array schema, this field was added in array
+          // schema evolution, ignore for this fragment's tile offsets
           if (!schema->is_field(name)) {
             continue;
           }
@@ -475,34 +473,31 @@ Status ReaderBase::load_tile_offsets(
 }
 
 Status ReaderBase::load_tile_var_sizes(
-    Subarray& subarray, const std::vector<std::string>& names) {
+    const RelevantFragments& relevant_fragments,
+    const std::vector<std::string>& names) {
   auto timer_se = stats_->start_timer("load_tile_var_sizes");
   const auto encryption_key = array_->encryption_key();
 
-  // Fetch relevant fragments so we load tile var sizes only from intersecting
-  // fragments
-  const auto relevant_fragments = subarray.relevant_fragments();
-
-  bool all_frag = !subarray.is_set();
-
   const auto status = parallel_for(
       storage_manager_->compute_tp(),
       0,
-      all_frag ? fragment_metadata_.size() : relevant_fragments->size(),
+      relevant_fragments.size(),
       [&](const uint64_t i) {
-        auto frag_idx = all_frag ? i : relevant_fragments->at(i);
+        auto frag_idx = relevant_fragments[i];
         auto& fragment = fragment_metadata_[frag_idx];
 
         const auto& schema = fragment->array_schema();
         for (const auto& name : names) {
-          // Not a member of array schema, this field was added in array schema
-          // evolution, ignore for this fragment's tile var sizes.
-          if (!schema->is_field(name))
+          // Not a member of array schema, this field was added in array
+          // schema evolution, ignore for this fragment's tile var sizes.
+          if (!schema->is_field(name)) {
             continue;
+          }
 
           // Not a var size attribute.
-          if (!schema->var_size(name))
+          if (!schema->var_size(name)) {
             continue;
+          }
 
           throw_if_not_ok(fragment->load_tile_var_sizes(*encryption_key, name));
         }
@@ -1520,8 +1515,8 @@ Status ReaderBase::unfilter_tiles(
             }
           }
 
-          // Unfilter 't' for fixed-sized tiles, otherwise unfilter both 't' and
-          // 't_var' for var-sized tiles.
+          // Unfilter 't' for fixed-sized tiles, otherwise unfilter both 't'
+          // and 't_var' for var-sized tiles.
           if (!var_size) {
             if (!nullable) {
               if (array_schema_.bitsort_filter_attr().has_value()) {
@@ -1716,6 +1711,10 @@ uint64_t ReaderBase::offsets_bytesize() const {
 uint64_t ReaderBase::get_attribute_tile_size(
     const std::string& name, unsigned f, uint64_t t) {
   uint64_t tile_size = 0;
+  if (!fragment_metadata_[f]->array_schema()->is_field(name)) {
+    return tile_size;
+  }
+
   tile_size += fragment_metadata_[f]->tile_size(name, t);
 
   if (array_schema_.var_size(name)) {
@@ -1742,33 +1741,16 @@ void ReaderBase::compute_result_space_tiles(
 
   // Compute fragment tile domains
   std::vector<TileDomain<T>> frag_tile_domains;
-
-  if (partitioner_subarray.is_set()) {
-    auto relevant_frags = partitioner_subarray.relevant_fragments();
-    for (auto it = relevant_frags->rbegin(); it != relevant_frags->rend();
-         it++) {
-      if (fragment_metadata_[*it]->dense()) {
-        frag_tile_domains.emplace_back(
-            *it,
-            domain,
-            fragment_metadata_[*it]->non_empty_domain(),
-            tile_extents,
-            tile_order);
-      }
-    }
-  } else {
-    auto fragment_num = (int)fragment_metadata_.size();
-    if (fragment_num > 0) {
-      for (int i = fragment_num - 1; i >= 0; --i) {
-        if (fragment_metadata_[i]->dense()) {
-          frag_tile_domains.emplace_back(
-              i,
-              domain,
-              fragment_metadata_[i]->non_empty_domain(),
-              tile_extents,
-              tile_order);
-        }
-      }
+  auto relevant_frags = partitioner_subarray.relevant_fragments();
+  for (size_t i = relevant_frags.size(); i > 0; --i) {
+    auto f = relevant_frags[i - 1];
+    if (fragment_metadata_[f]->dense()) {
+      frag_tile_domains.emplace_back(
+          f,
+          domain,
+          fragment_metadata_[f]->non_empty_domain(),
+          tile_extents,
+          tile_order);
     }
   }
 
@@ -1796,6 +1778,249 @@ bool ReaderBase::has_coords() const {
   return false;
 }
 
+template <typename IndexType>
+tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+ReaderBase::cache_dimension_label_data() {
+  // Cache the non empty domains and tile index for the first tile of each
+  // fragment.
+  auto index_dim{array_schema_.domain().dimension_ptr(0)};
+  const IndexType* dim_dom = index_dim->domain().typed_data<IndexType>();
+  auto tile_extent{index_dim->tile_extent().rvalue_as<IndexType>()};
+  std::vector<const void*> non_empty_domains(fragment_metadata_.size());
+  std::vector<uint64_t> frag_first_array_tile_idx(fragment_metadata_.size());
+  throw_if_not_ok(parallel_for(
+      storage_manager_->compute_tp(),
+      0,
+      fragment_metadata_.size(),
+      [&](unsigned f) {
+        non_empty_domains[f] =
+            fragment_metadata_[f]->non_empty_domain()[0].data();
+        auto ned = static_cast<const IndexType*>(non_empty_domains[f]);
+        frag_first_array_tile_idx[f] =
+            index_dim->tile_idx<IndexType>(ned[0], dim_dom[0], tile_extent);
+
+        return Status::Ok();
+      }));
+
+  // Compute the array non empty domain.
+  IndexType min = std::numeric_limits<IndexType>::max();
+  IndexType max = std::numeric_limits<IndexType>::min();
+  for (uint64_t f = 0; f < fragment_metadata_.size(); f++) {
+    auto ned = static_cast<const IndexType*>(non_empty_domains[f]);
+    min = std::min(min, ned[0]);
+    max = std::max(max, ned[1]);
+  }
+
+  return {Range(&min, &max, sizeof(IndexType)),
+          std::move(non_empty_domains),
+          std::move(frag_first_array_tile_idx)};
+}
+
+template <typename IndexType, typename AttributeType>
+void ReaderBase::validate_attribute_order(
+    std::string& attribute_name,
+    bool increasing_data,
+    Range& array_non_empty_domain,
+    std::vector<const void*>& non_empty_domains,
+    std::vector<uint64_t>& frag_first_array_tile_idx) {
+  // For only one fragment, no work to do.
+  if (fragment_metadata_.size() == 1) {
+    return;
+  }
+
+  // For easy reference.
+  auto array_min_idx = array_non_empty_domain.typed_data<IndexType>()[0];
+  auto array_max_idx = array_non_empty_domain.typed_data<IndexType>()[1];
+  auto index_dim{array_schema_.domain().dimension_ptr(0)};
+  auto index_name = index_dim->name();
+
+  // See if some values will already be processed by previous fragments.
+  AttributeOrderValidator validator(attribute_name, fragment_metadata_.size());
+  throw_if_not_ok(parallel_for(
+      storage_manager_->compute_tp(),
+      0,
+      fragment_metadata_.size(),
+      [&](uint64_t f) {
+        validator.find_fragments_to_check(
+            array_min_idx, array_max_idx, f, non_empty_domains);
+
+        return Status::Ok();
+      }));
+
+  throw_if_not_ok(parallel_for(
+      storage_manager_->compute_tp(),
+      0,
+      fragment_metadata_.size(),
+      [&](int64_t f) {
+        validator.validate_without_loading_tiles<IndexType, AttributeType>(
+            array_schema_,
+            index_dim,
+            increasing_data,
+            f,
+            non_empty_domains,
+            fragment_metadata_,
+            frag_first_array_tile_idx);
+        return Status::Ok();
+      }));
+
+  // If we need tiles to finish order validation, load them, then finish the
+  // validation.
+  if (validator.need_to_load_tiles()) {
+    auto tiles_to_load = validator.tiles_to_load();
+    throw_if_not_ok(read_attribute_tiles({attribute_name}, tiles_to_load));
+    throw_if_not_ok(unfilter_tiles(attribute_name, tiles_to_load));
+
+    // Validate bounds not validated using tile data.
+    throw_if_not_ok(parallel_for(
+        storage_manager_->compute_tp(),
+        0,
+        fragment_metadata_.size(),
+        [&](unsigned f) {
+          validator.validate_with_loaded_tiles<IndexType, AttributeType>(
+              index_dim,
+              increasing_data,
+              f,
+              non_empty_domains,
+              fragment_metadata_,
+              frag_first_array_tile_idx);
+          return Status::Ok();
+        }));
+  }
+}
+
+template <typename IndexType>
+void ReaderBase::validate_attribute_order(
+    Datatype attribute_type,
+    std::string& attribute_name,
+    bool increasing_data,
+    Range& array_non_empty_domain,
+    std::vector<const void*>& non_empty_domains,
+    std::vector<uint64_t>& frag_first_array_tile_idx) {
+  auto timer_se = stats_->start_timer("validate_attribute_order");
+
+  switch (attribute_type) {
+    case Datatype::INT8:
+      validate_attribute_order<IndexType, int8_t>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::UINT8:
+      validate_attribute_order<IndexType, uint8_t>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::INT16:
+      validate_attribute_order<IndexType, int16_t>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::UINT16:
+      validate_attribute_order<IndexType, uint16_t>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::INT32:
+      validate_attribute_order<IndexType, int32_t>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::UINT32:
+      validate_attribute_order<IndexType, uint32_t>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::INT64:
+      validate_attribute_order<IndexType, int64_t>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::UINT64:
+      validate_attribute_order<IndexType, uint64_t>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::FLOAT32:
+      validate_attribute_order<IndexType, float>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::FLOAT64:
+      validate_attribute_order<IndexType, double>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::DATETIME_YEAR:
+    case Datatype::DATETIME_MONTH:
+    case Datatype::DATETIME_WEEK:
+    case Datatype::DATETIME_DAY:
+    case Datatype::DATETIME_HR:
+    case Datatype::DATETIME_MIN:
+    case Datatype::DATETIME_SEC:
+    case Datatype::DATETIME_MS:
+    case Datatype::DATETIME_US:
+    case Datatype::DATETIME_NS:
+    case Datatype::DATETIME_PS:
+    case Datatype::DATETIME_FS:
+    case Datatype::DATETIME_AS:
+    case Datatype::TIME_HR:
+    case Datatype::TIME_MIN:
+    case Datatype::TIME_SEC:
+    case Datatype::TIME_MS:
+    case Datatype::TIME_US:
+    case Datatype::TIME_NS:
+    case Datatype::TIME_PS:
+    case Datatype::TIME_FS:
+    case Datatype::TIME_AS:
+      validate_attribute_order<IndexType, int64_t>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    case Datatype::STRING_ASCII:
+      validate_attribute_order<IndexType, std::string_view>(
+          attribute_name,
+          increasing_data,
+          array_non_empty_domain,
+          non_empty_domains,
+          frag_first_array_tile_idx);
+      break;
+    default:
+      throw ReaderBaseStatusException("Invalid attribute type");
+  }
+}
+
 void ReaderBase::calculate_hilbert_values(
     const DomainBuffersView& domain_buffers,
     std::vector<uint64_t>& hilbert_values) const {
@@ -1909,6 +2134,78 @@ template void ReaderBase::compute_result_space_tiles<uint64_t>(
     const Subarray&,
     const Subarray&,
     std::map<const uint64_t*, ResultSpaceTile<uint64_t>>&) const;
+template tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+ReaderBase::cache_dimension_label_data<int8_t>();
+template tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+ReaderBase::cache_dimension_label_data<uint8_t>();
+template tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+ReaderBase::cache_dimension_label_data<int16_t>();
+template tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+ReaderBase::cache_dimension_label_data<uint16_t>();
+template tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+ReaderBase::cache_dimension_label_data<int32_t>();
+template tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+ReaderBase::cache_dimension_label_data<uint32_t>();
+template tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+ReaderBase::cache_dimension_label_data<int64_t>();
+template tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+ReaderBase::cache_dimension_label_data<uint64_t>();
+template void ReaderBase::validate_attribute_order<int8_t>(
+    Datatype,
+    std::string&,
+    bool,
+    Range&,
+    std::vector<const void*>&,
+    std::vector<uint64_t>&);
+template void ReaderBase::validate_attribute_order<uint8_t>(
+    Datatype,
+    std::string&,
+    bool,
+    Range&,
+    std::vector<const void*>&,
+    std::vector<uint64_t>&);
+template void ReaderBase::validate_attribute_order<int16_t>(
+    Datatype,
+    std::string&,
+    bool,
+    Range&,
+    std::vector<const void*>&,
+    std::vector<uint64_t>&);
+template void ReaderBase::validate_attribute_order<uint16_t>(
+    Datatype,
+    std::string&,
+    bool,
+    Range&,
+    std::vector<const void*>&,
+    std::vector<uint64_t>&);
+template void ReaderBase::validate_attribute_order<int32_t>(
+    Datatype,
+    std::string&,
+    bool,
+    Range&,
+    std::vector<const void*>&,
+    std::vector<uint64_t>&);
+template void ReaderBase::validate_attribute_order<uint32_t>(
+    Datatype,
+    std::string&,
+    bool,
+    Range&,
+    std::vector<const void*>&,
+    std::vector<uint64_t>&);
+template void ReaderBase::validate_attribute_order<int64_t>(
+    Datatype,
+    std::string&,
+    bool,
+    Range&,
+    std::vector<const void*>&,
+    std::vector<uint64_t>&);
+template void ReaderBase::validate_attribute_order<uint64_t>(
+    Datatype,
+    std::string&,
+    bool,
+    Range&,
+    std::vector<const void*>&,
+    std::vector<uint64_t>&);
 
 }  // namespace sm
-}  // namespace tiledb
\ No newline at end of file
+}  // namespace tiledb
