@@ -322,20 +322,22 @@ class ReaderBase : public StrategyBase {
    * Loads tile offsets for each attribute/dimension name into
    * their associated element in `fragment_metadata_`.
    *
-   * @param subarray The subarray to load tiles for.
+   * @param relevant_fragments List of relevant fragments.
    * @param names The attribute/dimension names.
    * @return Status
    */
   Status load_tile_offsets(
-      Subarray& subarray, const std::vector<std::string>& names);
+      const RelevantFragments& relevant_fragments,
+      const std::vector<std::string>& names);
 
   /**
    * Checks if at least one fragment overlaps partially with the
    * time at which the read is taking place.
    *
+   * @param subarray Subarray to use.
    * @return True if at least one fragment partially overlaps.
    */
-  bool partial_consolidated_fragment_overlap() const;
+  bool partial_consolidated_fragment_overlap(Subarray& subarray) const;
 
   /**
    * Add a condition for partial time overlap based on array open and
@@ -353,12 +355,13 @@ class ReaderBase : public StrategyBase {
    * Loads tile var sizes for each attribute/dimension name into
    * their associated element in `fragment_metadata_`.
    *
-   * @param subarray The subarray to load tiles for.
+   * @param relevant_fragments List of relevant fragments.
    * @param names The attribute/dimension names.
    * @return Status
    */
   Status load_tile_var_sizes(
-      Subarray& subarray, const std::vector<std::string>& names);
+      const RelevantFragments& relevant_fragments,
+      const std::vector<std::string>& names);
 
   /**
    * Loads processed conditions from fragment metadata.
@@ -741,6 +744,64 @@ class ReaderBase : public StrategyBase {
       const bool var_size,
       const bool nullable) const;
 
+  /**
+   * Cache data to be used by dimension label code.
+   *
+   * @tparam Index type.
+   * @return non empty domain, non empty domains, fragment first array tile
+   * indexes.
+   */
+  template <typename IndexType>
+  tuple<Range, std::vector<const void*>, std::vector<uint64_t>>
+  cache_dimension_label_data();
+
+  /**
+   * Validates the attribute order for all loaded fragments.
+   *
+   * Throws an error if the there is a gap between fragments or the attribute
+   * order between fragments is not maintained.
+   *
+   * @tparam Index type
+   * @tparam Attribute type
+   * @param attribute_name Name of the attribute to validate.
+   * @param increasing_data Is the order of the data increasing?
+   * @param array_non_empty_domain Range storing the array non empty domain.
+   * @param non_empty_domains Pointer, per fragment, to the non empty domains.
+   * @param frag_first_array_tile_idx First tile index (in full domain), per
+   * fragment.
+   */
+  template <typename IndexType, typename AttributeType>
+  void validate_attribute_order(
+      std::string& attribute_name,
+      bool increasing_data,
+      Range& array_non_empty_domain,
+      std::vector<const void*>& non_empty_domains,
+      std::vector<uint64_t>& frag_first_array_tile_idx);
+
+  /**
+   * Validates the attribute order for all loaded fragments.
+   *
+   * Throws an error if the there is a gap between fragments or the attribute
+   * order between fragments is not maintained.
+   *
+   * @tparam Index type
+   * @param attribute_type Type of the attribute to validate.
+   * @param attribute_name Name of the attribute to validate.
+   * @param increasing_data Is the order of the data increasing?
+   * @param array_non_empty_domain Range storing the array non empty domain.
+   * @param non_empty_domains Pointer, per fragment, to the non empty domains.
+   * @param frag_first_array_tile_idx First tile index (in full domain), per
+   * fragment.
+   */
+  template <typename IndexType>
+  void validate_attribute_order(
+      Datatype attribute_type,
+      std::string& attribute_name,
+      bool increasing_data,
+      Range& array_non_empty_domain,
+      std::vector<const void*>& non_empty_domains,
+      std::vector<uint64_t>& frag_first_array_tile_idx);
+
  private:
   /**
    * @brief Class that stores all the storage needed to keep bitsort
@@ -759,7 +820,7 @@ class ReaderBase : public StrategyBase {
   /* ********************************* */
 
   /**
-   * @brief Calculate Hilbert values. Used to pass in a Hilbert
+   * Calculate Hilbert values. Used to pass in a Hilbert
    * comparator to the read-reverse path.
    *
    * @param domain_buffers
@@ -770,12 +831,12 @@ class ReaderBase : public StrategyBase {
       std::vector<uint64_t>& hilbert_values) const;
 
   /**
-   * @brief Constructs the bitsort metadata object.
+   * Constructs the bitsort metadata object.
    *
    * @tparam CmpObject The comparator object being constructed.
    * @param tile Fixed tile that is being unfiltered.
-   * @param bitsort_storage Storage for all the vectors needed to construct the
-   * bitsort filter.
+   * @param bitsort_storage Storage for all the vectors needed to construct
+   * the bitsort filter.
    * @return BitSortFilterMetadataType the constructed argument.
    */
 
@@ -792,4 +853,4 @@ class ReaderBase : public StrategyBase {
 }  // namespace sm
 }  // namespace tiledb
 
-#endif  // TILEDB_READER_BASE_H
\ No newline at end of file
+#endif  // TILEDB_READER_BASE_H
