@@ -335,6 +335,28 @@ uint64_t ResultTile::timestamp(uint64_t pos) {
   return tile.data_as<uint64_t>()[pos];
 }
 
+template <typename LabelType>
+LabelType ResultTile::attribute_value(
+    const std::string& label_name, const uint64_t pos) {
+  const auto label_data =
+      tile_tuple(label_name)->fixed_tile().data_as<LabelType>();
+  return label_data[pos];
+}
+
+template <>
+std::string_view ResultTile::attribute_value<std::string_view>(
+    const std::string& label_name, const uint64_t pos) {
+  auto tuple = tile_tuple(label_name);
+  auto offsets_data = tuple->fixed_tile().data_as<uint64_t>();
+  auto& var_tile = tuple->var_tile();
+  auto offset = offsets_data[pos];
+
+  auto size = static_cast<size_t>(pos) == cell_num() - 1 ?
+                  var_tile.size() - offset :
+                  offsets_data[pos + 1] - offset;
+  return std::string_view(&var_tile.data_as<char>()[offset], size);
+}
+
 unsigned ResultTile::frag_idx() const {
   return frag_idx_;
 }
@@ -1349,5 +1371,27 @@ void ResultTile::set_compute_results_func() {
   }
 }
 
+// Explicit template instantiations
+template int8_t ResultTile::attribute_value<int8_t>(
+    const std::string&, const uint64_t);
+template uint8_t ResultTile::attribute_value<uint8_t>(
+    const std::string&, const uint64_t);
+template int16_t ResultTile::attribute_value<int16_t>(
+    const std::string&, const uint64_t);
+template uint16_t ResultTile::attribute_value<uint16_t>(
+    const std::string&, const uint64_t);
+template int32_t ResultTile::attribute_value<int32_t>(
+    const std::string&, const uint64_t);
+template uint32_t ResultTile::attribute_value<uint32_t>(
+    const std::string&, const uint64_t);
+template int64_t ResultTile::attribute_value<int64_t>(
+    const std::string&, const uint64_t);
+template uint64_t ResultTile::attribute_value<uint64_t>(
+    const std::string&, const uint64_t);
+template float ResultTile::attribute_value<float>(
+    const std::string&, const uint64_t);
+template double ResultTile::attribute_value<double>(
+    const std::string&, const uint64_t);
+
 }  // namespace sm
 }  // namespace tiledb
