@@ -92,8 +92,10 @@ class GlobalOrderWriter : public WriterBase {
     /** The last hilbert value written. */
     uint64_t last_hilbert_value_;
 
-    /** A mapping of buffer names to multipart upload state used by clients
-     * to track the write state in remote global order writes */
+    /**
+     * A mapping of buffer names to multipart upload state used by clients
+     * to track the write state in remote global order writes
+     */
     std::unordered_map<std::string, VFS::MultiPartUploadState>
         multipart_upload_state_;
   };
@@ -112,6 +114,7 @@ class GlobalOrderWriter : public WriterBase {
       std::unordered_map<std::string, QueryBuffer>& buffers,
       Subarray& subarray,
       Layout layout,
+      uint64_t fragment_size,
       std::vector<WrittenFragmentInfo>& written_fragment_info,
       bool disable_checks_consolidation,
       std::vector<std::string>& processed_conditions,
@@ -187,6 +190,24 @@ class GlobalOrderWriter : public WriterBase {
   /** The processed conditions. */
   std::vector<std::string>& processed_conditions_;
 
+  /**
+   * List of fragment URIs to commit. This is the list of fragments that were
+   * written to disk but pending to be commited upon the success of the full
+   * write operation.
+   */
+  std::vector<URI> frag_uris_to_commit_;
+
+  /**
+   * The desired fragment size, in bytes. The writer will create a new fragment
+   * once this size has been reached.
+   */
+  uint64_t fragment_size_;
+
+  /**
+   * Size currently written to the fragment.
+   */
+  uint64_t current_fragment_size_;
+
   /* ********************************* */
   /*           PRIVATE METHODS         */
   /* ********************************* */
@@ -220,7 +241,7 @@ class GlobalOrderWriter : public WriterBase {
    * Invoked on error. It removes the directory of the input URI and
    * resets the global write state.
    */
-  void clean_up(const URI& uri);
+  void clean_up();
 
   /**
    * Computes the positions of the coordinate duplicates (if any). Note
@@ -341,6 +362,28 @@ class GlobalOrderWriter : public WriterBase {
       const std::string& name,
       const std::set<uint64_t>& coord_dups,
       WriterTileVector* tiles) const;
+
+  /**
+   * Return the number of tiles to write depending on the desired fragment
+   * size. The tiles passed in as an argument should have already been
+   * filtered.
+   *
+   * @param start Current tile index.
+   * @param tile_num Number of tiles in the tiles vectors.
+   * @param tiles Map of vector of tiles, per attributes.
+   * @return Number of tiles to write.
+   */
+  uint64_t num_tiles_to_write(
+      uint64_t start,
+      uint64_t tile_num,
+      std::unordered_map<std::string, WriterTileVector>& tiles);
+
+  /**
+   * Close the current fragment and start a new one. The closed fragment will
+   * be added to `frag_uris_to_commit_` so that all fragments in progress can
+   * be written at once.
+   */
+  Status start_new_fragment();
 };
 
 }  // namespace sm
