@@ -91,10 +91,16 @@ class UnorderedWriter : public WriterBase {
   /*         PRIVATE ATTRIBUTES        */
   /* ********************************* */
 
+  /** Fragment URI. */
+  std::optional<URI> frag_uri_;
+
   /* ********************************* */
   /*           PRIVATE METHODS         */
   /* ********************************* */
 
+  /** Invoked on error. It removes the directory of the input URI. */
+  void clean_up();
+
   /**
    * Throws an error if there are coordinate duplicates.
    *
@@ -104,12 +110,6 @@ class UnorderedWriter : public WriterBase {
    */
   Status check_coord_dups(const std::vector<uint64_t>& cell_pos) const;
 
-  /**
-   * Invoked on error. It removes the directory of the input URI and
-   * resets the global write state.
-   */
-  void clean_up(const URI& uri);
-
   /**
    * Computes the positions of the coordinate duplicates (if any). Note
    * that only the duplicate occurrences are determined, i.e., if the same
