@@ -223,6 +223,17 @@ class WriterBase : public StrategyBase, public IQueryStrategy {
    */
   void check_var_attr_offsets() const;
 
+  /**
+   * Throws an error if ordered data buffers do not have the expected sort.
+   *
+   * This method only checks currently loaded data. It does not check the
+   * sort of data in subsequent writes for the global order writer.
+   *
+   * For unordered writes, this method will need to be modified to take into
+   * account the sort order.
+   */
+  void check_attr_order() const;
+
   /**
    * Cleans up the coordinate buffers. Applicable only if the coordinate
    * buffers were allocated by TileDB (not the user)
