@@ -54,8 +54,8 @@
 
 #include "tiledb/common/logger.h"
 #include "tiledb/sm/array/array.h"
-#include "tiledb/sm/group/group.h"
 #include "tiledb/sm/enums/query_type.h"
+#include "tiledb/sm/group/group.h"
 #include "tiledb/sm/misc/constants.h"
 #include "tiledb/sm/misc/endian.h"
 #include "tiledb/sm/misc/parse_argument.h"
@@ -316,7 +316,7 @@ Status RestClient::post_array_from_rest(const URI& uri, Array* array) {
 }
 
 void RestClient::delete_array_from_rest(const URI& uri) {
-  /* #TODO Implement API endpoint on TileDBCloud. */
+  // #TODO Implement API endpoint on TileDBCloud.
   // Init curl and form the URL
   Curl curlc(logger_);
   std::string array_ns, array_uri;
@@ -1270,6 +1270,23 @@ Status RestClient::patch_group_to_rest(const URI& uri, Group* group) {
       stats_, url, serialization_type_, &serialized, &returned_data, cache_key);
 }
 
+void RestClient::delete_group_from_rest(const URI& uri) {
+  // #TODO Implement API endpoint on TileDBCloud.
+  // Init curl and form the URL
+  Curl curlc(logger_);
+  std::string group_ns, group_uri;
+  throw_if_not_ok(uri.get_rest_components(&group_ns, &group_uri));
+  const std::string cache_key = group_ns + ":" + group_uri;
+  throw_if_not_ok(
+      curlc.init(config_, extra_headers_, &redirect_meta_, &redirect_mtx_));
+  const std::string url = redirect_uri(cache_key) + "/v2/groups/" + group_ns +
+                          "/" + curlc.url_escape(group_uri);
+
+  Buffer returned_data;
+  throw_if_not_ok(curlc.delete_data(
+      stats_, url, serialization_type_, &returned_data, cache_key));
+}
+
 Status RestClient::ensure_json_null_delimited_string(Buffer* buffer) {
   if (serialization_type_ == SerializationType::JSON &&
       buffer->value<char>(buffer->size() - 1) != '\0') {
@@ -1420,6 +1437,11 @@ Status RestClient::patch_group_to_rest(const URI&, Group*) {
       Status_RestError("Cannot use rest client; serialization not enabled."));
 }
 
+void RestClient::delete_group_from_rest(const URI&) {
+  throw StatusException(
+      Status_RestError("Cannot use rest client; serialization not enabled."));
+}
+
 #endif  // TILEDB_SERIALIZATION
 
 }  // namespace sm
