@@ -63,7 +63,7 @@ Status fragment_info_request_to_capnp(
   // Set config
   auto config_builder = fragment_info_req_builder->initConfig();
   auto config = fragment_info.config();
-  RETURN_NOT_OK(config_to_capnp(&config, &config_builder));
+  RETURN_NOT_OK(config_to_capnp(config, &config_builder));
 
   return Status::Ok();
 }
@@ -367,7 +367,8 @@ Status fragment_info_to_capnp(
       fragment_info_builder->initFragmentInfo(frag_info.size());
   for (size_t i = 0; i < frag_info.size(); i++) {
     auto single_info_builder = frag_info_builder[i];
-    single_fragment_info_to_capnp(frag_info[i], &single_info_builder);
+    throw_if_not_ok(
+        single_fragment_info_to_capnp(frag_info[i], &single_info_builder));
   }
 
   // set fragment uris to vacuum
