@@ -150,38 +150,6 @@ class StorageManagerCanonical {
   /*                API                */
   /* ********************************* */
 
-  /**
-   * Closes an array opened for reads.
-   *
-   * @param array The array to be closed.
-   * @return Status
-   */
-  Status array_close_for_reads(Array* array);
-
-  /**
-   * Closes an array opened for writes.
-   *
-   * @param array The array to be closed.
-   * @return Status
-   */
-  Status array_close_for_writes(Array* array);
-
-  /**
-   * Closes an array opened for deletes.
-   *
-   * @param array The array to be closed.
-   * @return Status
-   */
-  Status array_close_for_deletes(Array* array);
-
-  /**
-   * Closes an array opened for updates.
-   *
-   * @param array The array to be closed.
-   * @return Status
-   */
-  Status array_close_for_updates(Array* array);
-
   /**
    * Closes an group opened for reads.
    *
@@ -473,6 +441,13 @@ class StorageManagerCanonical {
   Status delete_fragments(
       const char* array_name, uint64_t timestamp_start, uint64_t timestamp_end);
 
+  /**
+   * Cleans up the group data.
+   *
+   * @param group_name The name of the group whose data is to be deleted.
+   */
+  void delete_group(const char* group_name);
+
   /**
    * Cleans up the array, such as its consolidated fragments and array
    * metadata. Note that this will coarsen the granularity of time traveling
@@ -480,9 +455,8 @@ class StorageManagerCanonical {
    *
    * @param array_name The name of the array to be vacuumed.
    * @param config Configuration parameters for vacuuming.
-   * @return Status
    */
-  Status array_vacuum(const char* array_name, const Config& config);
+  void array_vacuum(const char* array_name, const Config& config);
 
   /**
    * Consolidates the metadata of an array into a single file.
@@ -1025,21 +999,6 @@ class StorageManagerCanonical {
   Status store_metadata(
       const URI& uri, const EncryptionKey& encryption_key, Metadata* metadata);
 
-  /**
-   * Stores data into persistent storage.
-   *
-   * @param data Data to store.
-   * @param size Size of the data.
-   * @param uri The object URI.
-   * @param encryption_key The encryption key to use.
-   * @return Status
-   */
-  Status store_data_to_generic_tile(
-      void* data,
-      const size_t size,
-      const URI& uri,
-      const EncryptionKey& encryption_key);
-
   /**
    * Stores data into persistent storage.
    *
@@ -1112,9 +1071,8 @@ class StorageManagerCanonical {
    * @param config Configuration parameters for vacuuming
    *     (`nullptr` means default, which will use the config associated with
    *      this instance).
-   * @return Status
    */
-  Status group_metadata_vacuum(const char* group_name, const Config& config);
+  void group_metadata_vacuum(const char* group_name, const Config& config);
 
  private:
   /* ********************************* */
@@ -1180,12 +1138,6 @@ class StorageManagerCanonical {
   /** Stores the TileDB configuration parameters. */
   Config config_;
 
-  /** Keeps track of which arrays are open. */
-  std::set<Array*> open_arrays_;
-
-  /** Mutex for managing open arrays. */
-  std::mutex open_arrays_mtx_;
-
   /** Keeps track of which groups are open. */
   std::set<Group*> open_groups_;
 
@@ -1272,7 +1224,7 @@ class StorageManagerCanonical {
           array_schemas_all,
       const EncryptionKey& encryption_key,
       const std::vector<TimestampedURI>& fragments_to_load,
-      const std::unordered_map<std::string, std::pair<Buffer*, uint64_t>>&
+      const std::unordered_map<std::string, std::pair<Tile*, uint64_t>>&
           offsets);
 
   /**
@@ -1286,7 +1238,7 @@ class StorageManagerCanonical {
    */
   tuple<
       Status,
-      optional<Buffer>,
+      optional<Tile>,
       optional<std::vector<std::pair<std::string, uint64_t>>>>
   load_consolidated_fragment_meta(const URI& uri, const EncryptionKey& enc_key);
 
