@@ -49,9 +49,6 @@ class TileStatusException : public StatusException {
   }
 };
 
-void nop_free(void* const) {
-}
-
 /* ****************************** */
 /*           STATIC INIT          */
 /* ****************************** */
@@ -114,21 +111,6 @@ Tile::Tile(
     , filtered_buffer_(filtered_size) {
 }
 
-Tile::Tile(
-    const Datatype type,
-    const uint64_t cell_size,
-    const unsigned int zipped_coords_dim_num,
-    void* const buffer,
-    uint64_t size)
-    : data_(static_cast<char*>(buffer), nop_free)
-    , size_(size)
-    , cell_size_(cell_size)
-    , zipped_coords_dim_num_(zipped_coords_dim_num)
-    , format_version_(0)
-    , type_(type)
-    , filtered_buffer_(0) {
-}
-
 Tile::Tile(Tile&& tile)
     : data_(std::move(tile.data_))
     , size_(std::move(tile.size_))
